@@ -50,11 +50,18 @@
 void
 callback_show_next_live_game(void)
 {
+#ifdef DEBUG
+    printf("callback_show_next_live_game\n");
+#endif
+
     gint i, j;
 
     for(i=0;i<users->len;i++)
 	usr(i).counters[COUNT_USER_TOOK_TURN] = 0;
 
+    counters[COUNT_NEWS_SHOWN] = 
+        counters[COUNT_NEW_NEWS] = 0;
+
     for(i=0;i<ligs->len;i++)
 	for(j=0;j<lig(i).fixtures->len;j++)
 	    if(g_array_index(lig(i).fixtures, Fixture, j).week_number == week &&
@@ -65,7 +72,8 @@ callback_show_next_live_game(void)
 			  &usr(fixture_user_team_involved(&g_array_index(lig(i).fixtures, Fixture, j))).
 			  options))
 	    {
-		live_game_calculate_fixture(&g_array_index(lig(i).fixtures, Fixture, j));
+		live_game_calculate_fixture(&g_array_index(lig(i).fixtures, Fixture, j), 
+                                            &usr(fixture_user_team_involved(&g_array_index(lig(i).fixtures, Fixture, j))).live_game);
 		return;
 	    }
 
@@ -79,8 +87,9 @@ callback_show_next_live_game(void)
 			  &usr(fixture_user_team_involved(&g_array_index(acp(i)->fixtures, Fixture, j))).
 			  options))
 	    {
-		live_game_calculate_fixture(&g_array_index(acp(i)->fixtures, Fixture, j));
-		return;
+		live_game_calculate_fixture(&g_array_index(acp(i)->fixtures, Fixture, j), 
+                                            &usr(fixture_user_team_involved(&g_array_index(acp(i)->fixtures, Fixture, j))).live_game);
+ 		return;
 	    }
 
     window_destroy(&window.live);
@@ -91,56 +100,73 @@ callback_show_next_live_game(void)
     setsav0;
 }
 
+/** Handle either a left click or a return button press
+    on the player list.
+    @param idx The player number. */
+void
+callback_player_activate(gint idx)
+{
+#ifdef DEBUG
+    printf("callback_player_activate\n");
+#endif
+
+    if(stat0 == STATUS_SHOW_TRANSFER_LIST)
+    {
+	selected_row = -1;
+	transfer_add_remove_user_player(player_of_idx_team(current_user.tm, idx));
+    }
+    else if(stat0 == STATUS_SHOW_YA)
+    {
+	selected_row = idx;
+	on_menu_move_to_youth_academy_activate(NULL, NULL);
+    }
+    else
+    {
+	if(selected_row == -1)
+	{
+	    selected_row = idx;
+	    return;
+	}
+
+	player_swap(current_user.tm, selected_row,
+		    current_user.tm, idx);
+
+	if(opt_user_int("int_opt_user_swap_adapts") == 1 &&
+	   current_user.tm->structure !=
+	   team_find_appropriate_structure(current_user.tm))
+	{
+	    team_change_structure(current_user.tm,
+				  team_find_appropriate_structure(current_user.tm));
+	    team_rearrange(current_user.tm);
+	}
+
+	game_gui_write_av_skills(NULL);
+
+	selected_row = -1;
+
+	treeview_show_user_player_list();
+	if(stat0 == STATUS_MAIN)
+	    treeview_show_next_opponent();
+    }
+
+}
+
 /** Handle a click on the player list.
     @param idx The player number.
     @param event The type of button click. */
 void
 callback_player_clicked(gint idx, GdkEventButton *event)
 {
+#ifdef DEBUG
+    printf("callback_player_clicked\n");
+#endif
+
     /* Only accept single-clicks right now. */
     if(event->type != GDK_BUTTON_PRESS)
 	return;
 
     if(event->button == 1)
-    {
-	if(stat0 == STATUS_SHOW_TRANSFER_LIST)
-	{
-	    selected_row = -1;
-	    transfer_add_remove_user_player(player_of_idx_team(current_user.tm, idx));
-	}
-	else if(stat0 == STATUS_SHOW_YA)
-	{
-	    selected_row = idx;
-	    on_menu_move_to_youth_academy_activate(NULL, NULL);
-	}
-	else
-	{
-	    if(selected_row == -1)
-	    {
-		selected_row = idx;
-		return;
-	    }
-
-	    player_swap(current_user.tm, selected_row,
-			current_user.tm, idx);
-	    if(opt_user_int("int_opt_user_swap_adapts") == 1 &&
-	       current_user.tm->structure !=
-	       team_find_appropriate_structure(current_user.tm))
-	    {
-		team_change_structure(current_user.tm,
-				      team_find_appropriate_structure(current_user.tm));
-		team_rearrange(current_user.tm);
-	    }
-
-	    game_gui_write_av_skills(NULL);
-
-	    selected_row = -1;
-
-	    treeview_show_user_player_list();
-	    if(stat0 == STATUS_MAIN)
-		treeview_show_next_opponent();
-	}
-    }
+	callback_player_activate(idx);
     else if(event->button == 3)
     {
 	selected_row = idx;
@@ -155,6 +181,10 @@ callback_player_clicked(gint idx, GdkEventButton *event)
 void
 callback_show_last_match(gboolean start, LiveGame *lg)
 {
+#ifdef DEBUG
+    printf("callback_show_last_match\n");
+#endif
+
     gint i;
 
     stat4 = -1;
@@ -207,6 +237,10 @@ callback_show_last_match(gboolean start, LiveGame *lg)
 void
 callback_show_last_match_stats(void)
 {
+#ifdef DEBUG
+    printf("callback_show_last_match_stats\n");
+#endif
+
     current_user.live_game.fix = 
 	fixture_from_id(current_user.live_game.fix_id, TRUE);
     
@@ -220,6 +254,10 @@ callback_show_last_match_stats(void)
 void
 callback_show_fixtures_week(gint type)
 {
+#ifdef DEBUG
+    printf("callback_show_fixtures_week\n");
+#endif
+
     switch(type)
     {
 	default:
@@ -260,6 +298,10 @@ callback_show_fixtures_week(gint type)
 void
 callback_show_fixtures(gint type)
 {
+#ifdef DEBUG
+    printf("callback_show_fixtures\n");
+#endif
+
     const Fixture *fix = fixture_get(type, stat1, stat2, stat3,
 				     current_user.tm);
 
@@ -276,10 +318,14 @@ callback_show_fixtures(gint type)
 void
 callback_show_tables(gint type)
 {
+#ifdef DEBUG
+    printf("callback_show_tables\n");
+#endif
+
     gint clid = -1;
 
     if(type == SHOW_CURRENT)
-	clid = team_get_table_clid(current_user.tm);
+	clid = stat1;
     else if(type == SHOW_NEXT_LEAGUE)
 	clid = league_cup_get_next_clid(stat1, FALSE);
     else if(type == SHOW_PREVIOUS_LEAGUE)
@@ -290,7 +336,7 @@ callback_show_tables(gint type)
 	return;
     }
 
-    while((clid < ID_CUP_START && !league_from_clid(clid)->active) ||
+    while((clid < ID_CUP_START && !query_league_active(league_from_clid(clid))) ||
 	  (clid >= ID_CUP_START && cup_has_tables(clid) == -1))
     {
 	if(type == SHOW_PREVIOUS_LEAGUE)
@@ -309,6 +355,10 @@ callback_show_tables(gint type)
 void
 callback_get_loan(void)
 {
+#ifdef DEBUG
+    printf("callback_get_loan\n");
+#endif
+
     gchar buf[SMALL], buf2[SMALL];
     gint max_loan = 
 	finance_team_drawing_credit_loan(current_user.tm, TRUE) + current_user.debt;
@@ -323,13 +373,17 @@ callback_get_loan(void)
     misc_print_grouped_int(max_loan, buf2);
     sprintf(buf, _("You can take out at most %s."), buf2);
 
-    window_show_digits(buf, _("Loan"), max_loan, NULL, 0);
+    window_show_digits(buf, _("Loan"), max_loan, NULL, 0, TRUE);
 }
 
 /** Open the digits window to pay back a loan. */
 void
 callback_pay_loan(void)
 {
+#ifdef DEBUG
+    printf("callback_pay_loan\n");
+#endif
+
     gchar buf[SMALL], buf2[SMALL];
     gint max_payback = MIN(BUDGET(cur_user), -current_user.debt);
 
@@ -349,7 +403,7 @@ callback_pay_loan(void)
     misc_print_grouped_int(max_payback, buf2);
     sprintf(buf, _("You can pay back at most %s"), buf2);
 
-    window_show_digits(buf, _("Payback"), max_payback, NULL, 0);
+    window_show_digits(buf, _("Payback"), max_payback, NULL, 0, FALSE);
 }
 
 /** Manage a click on a player of the current team on the
@@ -359,6 +413,10 @@ callback_pay_loan(void)
 void
 callback_transfer_list_user(gint button, gint idx)
 {
+#ifdef DEBUG
+    printf("callback_transfer_list_user\n");
+#endif
+
     gchar buf[SMALL],
 	buf2[SMALL], buf3[SMALL];
 
@@ -401,6 +459,10 @@ callback_transfer_list_user(gint button, gint idx)
 void
 callback_transfer_list_cpu(gint button, gint idx)
 {
+#ifdef DEBUG
+    printf("callback_transfer_list_cpu\n");
+#endif
+
     gchar buf[SMALL], buf2[SMALL], buf3[SMALL];
 
     if(button == 2)
@@ -439,6 +501,10 @@ callback_transfer_list_cpu(gint button, gint idx)
 void
 callback_transfer_list_clicked(gint button, gint idx)
 {
+#ifdef DEBUG
+    printf("callback_transfer_list_clicked\n");
+#endif
+
     gchar buf[SMALL];
     Transfer *tr = &trans(idx);
     gint old_fee, old_wage = -1;
@@ -485,14 +551,14 @@ callback_transfer_list_clicked(gint button, gint idx)
 		player_of_id_team(tr->tm, tr->id)->name);
 	
 	window_show_digits(buf, _("Fee"), tr->fee[current_user.scout % 10],
-			   _("Wage"), tr->wage[current_user.scout % 10]);
+			   _("Wage"), tr->wage[current_user.scout % 10], FALSE);
     }
     else
     {
 	sprintf(buf, _("You are making an offer for %s again. Your previous values for fee and wage are preset."),
 		player_of_id_team(tr->tm, tr->id)->name);
 	
-	window_show_digits(buf, _("Fee"), old_fee, _("Wage"), old_wage);
+	window_show_digits(buf, _("Fee"), old_fee, _("Wage"), old_wage, FALSE);
     }
 }
 
@@ -500,6 +566,10 @@ callback_transfer_list_clicked(gint button, gint idx)
 void
 callback_offer_new_contract(gint idx)
 {
+#ifdef DEBUG
+    printf("callback_offer_new_contract\n");
+#endif
+
     gint i;
     gchar buf[SMALL];
     Player *pl = player_of_idx_team(current_user.tm, idx);
@@ -518,6 +588,12 @@ callback_offer_new_contract(gint idx)
 	game_gui_show_warning(_("The player won't negotiate with you anymore."));
 	return;
     }
+    else if(query_player_star_balks(pl, current_user.tm, FALSE))
+    {
+	pl->offers = const_int("int_contract_max_offers");
+	game_gui_show_warning(_("The player feels he doesn't have a future in your star-studded team. He refuses to negotiate."));
+	return;
+    }
 
     stat1 = player_assign_wage(pl);
     statp = (gpointer)pl;
@@ -553,6 +629,10 @@ callback_offer_new_contract(gint idx)
 void
 callback_show_team(gint type)
 {
+#ifdef DEBUG
+    printf("callback_show_team\n");
+#endif
+
     GtkTreeView *treeview_right = 
 	GTK_TREE_VIEW(lookup_widget(window.main, "treeview_right"));
     const Team *tm;
@@ -620,6 +700,10 @@ callback_show_team(gint type)
 void
 callback_show_player_list(gint type)
 {
+#ifdef DEBUG
+    printf("callback_show_player_list\n");
+#endif
+
     stat0 = STATUS_SHOW_PLAYER_LIST;
 
     switch(type)
@@ -650,6 +734,10 @@ callback_show_player_list(gint type)
 void
 callback_fire_player(gint idx)
 {
+#ifdef DEBUG
+    printf("callback_fire_player\n");
+#endif
+
     gchar buf[SMALL], buf2[SMALL];
     Player *pl = player_of_idx_team(current_user.tm, idx);
 
@@ -669,6 +757,10 @@ callback_fire_player(gint idx)
 void
 callback_show_league_stats(gint type)
 {
+#ifdef DEBUG
+    printf("callback_show_league_stats\n");
+#endif
+
     switch(type)
     {
 	default:
@@ -678,7 +770,7 @@ callback_show_league_stats(gint type)
 	case SHOW_CURRENT:
 	    stat1 = current_user.tm->clid;
 	    while(stat1 >= ID_CUP_START ||
-		  !league_from_clid(stat1)->active)
+		  !query_league_active(league_from_clid(stat1)))
 		stat1 = league_cup_get_next_clid(stat1, FALSE);
 	    break;
 	case SHOW_NEXT_LEAGUE:
@@ -700,6 +792,10 @@ callback_show_league_stats(gint type)
 void
 callback_show_season_history(gint type)
 {
+#ifdef DEBUG
+    printf("callback_show_season_history\n");
+#endif
+
     const SeasonStat *stat = NULL;
     gint len = season_stats->len;
 
@@ -717,7 +813,7 @@ callback_show_season_history(gint type)
 	    stat = &g_array_index(season_stats, SeasonStat, stat2);
 	    if(stat1 == -1)
 		stat1 = 0;
-	    else if(stat1 == stat->league_champs->len - 1)
+	    else if(stat1 == stat->league_stats->len - 1)
 		stat1 = -1;
 	    else
 		stat1++;
@@ -725,7 +821,7 @@ callback_show_season_history(gint type)
 	case SHOW_PREVIOUS_LEAGUE:
 	    stat = &g_array_index(season_stats, SeasonStat, stat2);
 	    if(stat1 == -1)
-		stat1 = stat->league_champs->len - 1;
+		stat1 = stat->league_stats->len - 1;
 	    else if(stat1 == 0)
 		stat1 = -1;
 	    else
@@ -738,7 +834,7 @@ callback_show_season_history(gint type)
 	    stat2 = (stat2 == 0) ? len - 1 : stat2 - 1;
 	    break;
     }
-    
+
     treeview_show_season_history(stat1, stat2);
 }
 
@@ -746,6 +842,10 @@ callback_show_season_history(gint type)
 void
 callback_show_next_opponent(void)
 {
+#ifdef DEBUG
+    printf("callback_show_next_opponent\n");
+#endif
+
     const Fixture *fix = team_get_fixture(current_user.tm, FALSE);
     const Team *opp = (fix == NULL) ? NULL :
 	fix->teams[fix->teams[0] == current_user.tm];
@@ -767,6 +867,10 @@ callback_show_next_opponent(void)
 void
 callback_show_player_team(void)
 {
+#ifdef DEBUG
+    printf("callback_show_player_team\n");
+#endif
+
     GtkTreeView *treeview_right = 
 	GTK_TREE_VIEW(lookup_widget(window.main, "treeview_right"));
     const Player *pl = 
@@ -783,6 +887,10 @@ callback_show_player_team(void)
 void
 callback_show_youth_academy(void)
 {
+#ifdef DEBUG
+    printf("callback_show_youth_academy\n");
+#endif
+
     gint i;
     PlayerListAttribute attributes;
 
