@@ -23,9 +23,12 @@
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
+#include <gdk/gdkkeysyms.h>
+
 #include "callbacks.h"
 #include "callback_func.h"
 #include "debug.h"
+#include "fixture.h"
 #include "free.h"
 #include "game.h"
 #include "game_gui.h"
@@ -51,6 +54,10 @@ on_button_quit_clicked                 (GtkWidget       *widget,
                                         GdkEvent        *event,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_button_quit_clicked\n");
+#endif
+
     on_menu_quit_activate(NULL, NULL);
 
     return TRUE;
@@ -61,12 +68,17 @@ void
 on_menu_new_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_new_activate\n");
+#endif
+
     window_destroy(&window.main);
     free_memory();
     
     main_init(NULL, NULL);
     window_show_startup();
     stat0 = STATUS_TEAM_SELECTION;
+    statp = NULL;
 }
 
 
@@ -74,6 +86,10 @@ void
 on_menu_open_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_open_activate\n");
+#endif
+
     stat5 = STATUS_LOAD_GAME;
     window_show_file_sel();
 }
@@ -83,6 +99,10 @@ void
 on_menu_save_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_save_activate\n");
+#endif
+
     if(!opt_int("int_opt_save_will_overwrite") ||
        save_file == NULL)
 	on_menu_save_as_activate(NULL, NULL);
@@ -95,6 +115,10 @@ void
 on_menu_save_as_activate               (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_save_as_activate\n");
+#endif
+
     stat5 = STATUS_SAVE_GAME;
     window_show_file_sel();
 }
@@ -103,6 +127,10 @@ void
 on_menu_quit_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_quit_activate\n");
+#endif
+
     if(!getsav || !opt_int("int_opt_confirm_quit"))
 	main_exit_program(EXIT_OK, NULL);
     else
@@ -119,6 +147,10 @@ void
 on_menu_help_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_help_activate\n");
+#endif
+
     window_show_help(2);
 }
 
@@ -127,6 +159,10 @@ void
 on_menu_contributors_activate          (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_contributors_activate\n");
+#endif
+
     window_show_help(1);
 }
 
@@ -135,6 +171,10 @@ void
 on_menu_about_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_about_activate\n");
+#endif
+
     window_show_help(0);
 }
 
@@ -143,6 +183,10 @@ void
 on_button_load_clicked                 (GtkButton       *button,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_button_load_clicked\n");
+#endif
+
     on_menu_open_activate(NULL, NULL);
 }
 
@@ -151,6 +195,10 @@ void
 on_button_save_clicked                 (GtkButton       *button,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_button_save_clicked\n");
+#endif
+
     on_menu_save_activate(NULL, NULL);
 }
 
@@ -159,12 +207,24 @@ void
 on_button_back_to_main_clicked         (GtkButton       *button,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_button_back_to_main_clicked\n");
+#endif
+
     if(stat0 != STATUS_LIVE_GAME_PAUSE)
 	stat0 = STATUS_MAIN;
     gtk_notebook_set_current_page(GTK_NOTEBOOK(lookup_widget(window.main, "notebook_player")), 0);
+    selected_row = -1;
     game_gui_show_main();
 
     gui_set_arrows();
+
+    if((opt_int("int_opt_news_popup") == 2 ||
+        (opt_int("int_opt_news_popup") == 1 &&
+         counters[COUNT_NEW_NEWS] == 1)) &&
+       counters[COUNT_NEWS_SHOWN] == 0 &&
+       counters[COUNT_NEW_NEWS] != 0)
+        on_menu_news_activate(NULL, NULL);
 }
 
 
@@ -172,6 +232,10 @@ void
 on_button_transfers_clicked            (GtkButton       *button,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_button_transfers_clicked\n");
+#endif
+
     if(sett_int("int_opt_disable_transfers"))
 	game_gui_print_message(_("Transfers are disabled in this country definition."));
     else if(week < transfer_get_deadline() || transfer_list->len > 0)
@@ -201,6 +265,10 @@ void
 on_button_new_week_clicked             (GtkButton       *button,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_button_new_week_clicked\n");
+#endif
+
     if(transfer_offers_pending())
 	game_gui_show_warning(_("You still have some transfer business to manage."));
     else if(query_user_no_turn())
@@ -227,6 +295,10 @@ on_player_list1_button_press_event     (GtkWidget       *widget,
                                         GdkEventButton  *event,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_player_list1_button_press_event\n");
+#endif
+
     gint idx = -1;
 
     if(event->button == 2)
@@ -248,16 +320,49 @@ on_player_list1_button_press_event     (GtkWidget       *widget,
 	selected_row = -1;
 	return FALSE;
     }
-
+ 
     callback_player_clicked(idx - 1, event);
 
     return FALSE;
 }
 
+
+gboolean
+on_player_list1_key_press_event        (GtkWidget       *widget,
+                                        GdkEventKey     *event,
+                                        gpointer         user_data)
+{
+#ifdef DEBUG
+    printf("on_player_list1_key_press_event\n");
+#endif
+
+    gint idx = -1;
+
+    if(event->keyval != GDK_Return)
+	return FALSE;
+
+    idx = treeview_helper_get_index(GTK_TREE_VIEW(widget), 0);
+
+    if(idx < 0 || idx - 1 == selected_row)
+    {
+	selected_row = -1;
+	return FALSE;
+    }
+
+    callback_player_activate(idx - 1);
+
+    return FALSE;
+}
+
+
 void
 on_button_browse_forward_clicked       (GtkButton       *button,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_button_browse_forward_clicked\n");
+#endif
+
     switch(stat0)
     {
 	case STATUS_SHOW_FIXTURES:
@@ -284,6 +389,10 @@ void
 on_button_browse_back_clicked          (GtkButton       *button,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_button_browse_back_clicked\n");
+#endif
+
     switch(stat0)
     {
 	case STATUS_SHOW_FIXTURES:
@@ -309,6 +418,10 @@ void
 on_button_cl_back_clicked              (GtkButton       *button,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_button_cl_back_clicked\n");
+#endif
+
     switch(stat0)
     {
 	case STATUS_SHOW_FIXTURES:
@@ -336,6 +449,10 @@ void
 on_button_cl_forward_clicked           (GtkButton       *button,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_button_cl_forward_clicked\n");
+#endif
+
     switch(stat0)
     {
 	case STATUS_SHOW_FIXTURES:
@@ -364,6 +481,10 @@ void
 on_menu_preferences_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_preferences_activate\n");
+#endif
+
     window_show_options();
 }
 
@@ -371,6 +492,13 @@ void
 on_menu_fixtures_activate              (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_fixtures_activate\n");
+#endif
+
+    game_gui_print_message(
+        _("Left click to show table."));
+
     stat0 = STATUS_SHOW_FIXTURES;
     callback_show_fixtures(SHOW_TEAM);
 
@@ -381,6 +509,10 @@ void
 on_menu_fixtures_week_activate         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_fixtures_week_activate\n");
+#endif
+
     stat0 = STATUS_SHOW_FIXTURES_WEEK;
     callback_show_fixtures_week(SHOW_CURRENT);
 
@@ -392,6 +524,10 @@ void
 on_menu_tables_activate                (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_tables_activate\n");
+#endif
+
     /* No tables in this country? */
     if(!query_tables_in_country())
     {
@@ -400,7 +536,11 @@ on_menu_tables_activate                (GtkMenuItem     *menuitem,
 	return;
     }
 
+    game_gui_print_message(
+        _("Left click to show fixtures."));
+
     stat0 = STATUS_SHOW_TABLES;
+    stat1 = team_get_table_clid(current_user.tm);
     callback_show_tables(SHOW_CURRENT);
 
     gui_set_arrows();
@@ -411,6 +551,10 @@ void
 on_menu_league_stats_activate          (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_league_stats_activate\n");
+#endif
+
     if(!query_leagues_active_in_country())
     {
 	game_gui_print_message(
@@ -429,6 +573,10 @@ void
 on_menu_season_history_activate        (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_season_history_activate\n");
+#endif
+
     if(season_stats->len == 0)
     {
 	game_gui_print_message(
@@ -447,6 +595,10 @@ void
 on_menu_put_on_transfer_list_activate  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_put_on_transfer_list_activate\n");
+#endif
+
     if(sett_int("int_opt_disable_transfers"))
 	game_gui_print_message(_("Transfers are disabled in this country definition."));
     else if(selected_row == -1)
@@ -465,6 +617,10 @@ void
 on_menu_remove_from_transfer_list_activate (GtkMenuItem     *menuitem,
 					    gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_remove_from_transfer_list_activate\n");
+#endif
+
     if(selected_row == -1)
 	game_gui_print_message(_("You haven't selected a player."));
     else if(!query_transfer_player_is_on_list(player_of_idx_team(current_user.tm, selected_row)))
@@ -481,6 +637,10 @@ void
 on_menu_fire_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_fire_activate\n");
+#endif
+
     if(selected_row == -1)
 	game_gui_print_message(_("You haven't selected a player."));
     else if(current_user.tm->players->len == 11)
@@ -497,6 +657,10 @@ void
 on_menu_shoots_penalties_activate      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_shoots_penalties_activate\n");
+#endif
+
     if(selected_row == -1)
 	game_gui_print_message(_("You haven't selected a player."));
     else if(player_of_idx_team(current_user.tm, selected_row)->id ==
@@ -523,6 +687,10 @@ void
 on_menu_move_to_youth_academy_activate (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_move_to_youth_academy_activate\n");
+#endif
+
     Player *pl;
 
     if(sett_int("int_opt_disable_ya"))
@@ -561,6 +729,10 @@ void
 on_menu_my_league_results_activate     (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_my_league_results_activate\n");
+#endif
+
     stat0 = STATUS_SHOW_LEAGUE_RESULTS;
     treeview_show_league_results(GTK_TREE_VIEW(lookup_widget(window.main, "treeview_right")));
 
@@ -573,6 +745,10 @@ void
 on_menu_season_results_activate        (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_season_results_activate\n");
+#endif
+
     stat0 = STATUS_SHOW_SEASON_RESULTS;
     treeview2_show_season_results();
     gui_set_arrows();
@@ -583,6 +759,10 @@ void
 on_menu_browse_teams_activate          (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_browse_teams_activate\n");
+#endif
+
     GtkWidget *treeview_right =
 	lookup_widget(window.main, "treeview_right");
 
@@ -599,6 +779,10 @@ on_treeview_right_button_press_event   (GtkWidget       *widget,
                                         GdkEventButton  *event,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_treeview_right_button_press_event\n");
+#endif
+
     gint idx;
 
     if(stat0 == STATUS_SHOW_FINANCES)
@@ -672,8 +856,24 @@ on_treeview_right_button_press_event   (GtkWidget       *widget,
 		    setsav0;
 		}
 	    break;
-    }
 
+    case STATUS_SHOW_TABLES:
+        stat0 = STATUS_SHOW_FIXTURES;
+        stat2 = week;
+        stat3 = week_round;
+        callback_show_fixtures(SHOW_CURRENT);
+        break;
+    case STATUS_SHOW_FIXTURES:
+        if(stat1 >= ID_CUP_START && cup_has_tables(stat1) == -1)
+            game_gui_print_message(_("Cup has no tables."));
+        else
+        {
+            stat0 = STATUS_SHOW_TABLES;
+            callback_show_tables(SHOW_CURRENT);   
+        }
+        break;
+    }
+    
     gui_set_arrows();
 
     return TRUE;
@@ -683,6 +883,10 @@ void
 on_menu_next_user_activate             (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_next_user_activate\n");
+#endif
+
     if(transfer_offers_pending())
     {
 	game_gui_show_warning(_("You still have some transfer business to manage."));
@@ -700,6 +904,10 @@ void
 on_menu_previous_user_activate         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_previous_user_activate\n");
+#endif
+
     if(transfer_offers_pending())
     {
 	game_gui_show_warning(_("You still have some transfer business to manage."));
@@ -717,9 +925,13 @@ void
 on_menu_custom_structure_activate      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_custom_structure_activate\n");
+#endif
+
     stat1 = STATUS_CUSTOM_STRUCTURE;
     window_show_digits(_("Enter a structure. The digits must sum up to 10."),
-		       NULL, -1, _("Structure"), current_user.tm->structure);
+		       NULL, -1, _("Structure"), current_user.tm->structure, FALSE);
 }
 
 
@@ -728,6 +940,10 @@ on_menu_team_button_release_event        (GtkWidget       *widget,
 					  GdkEventButton  *event,
 					  gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_team_button_release_event\n");
+#endif
+
     game_gui_read_radio_items(widget);
     setsav0;
 
@@ -738,6 +954,10 @@ void
 on_menu_manage_users_activate          (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_manage_users_activate\n");
+#endif
+
     stat0 = stat1 = STATUS_USER_MANAGEMENT;
     window_create(WINDOW_USER_MANAGEMENT);
     treeview_show_users(GTK_TREE_VIEW(lookup_widget(window.user_management, "treeview_user_management_users")));
@@ -750,6 +970,10 @@ void
 on_menu_user_show_last_match_activate  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_user_show_last_match_activate\n");
+#endif
+
     if(current_user.live_game.units->len == 0)
     {
 	game_gui_show_warning(_("No match stored."));
@@ -766,6 +990,10 @@ void
 on_menu_user_show_last_stats_activate  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_user_show_last_stats_activate\n");
+#endif
+
     if(current_user.live_game.units->len == 0)
     {
 	game_gui_show_warning(_("No match stored."));
@@ -784,6 +1012,10 @@ on_menu_user_show_coming_matches_activate
                                         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_user_show_coming_matches_activate\n");
+#endif
+
     stat0 = STATUS_SHOW_PREVIEW;
     treeview_show_preview();
 
@@ -796,6 +1028,10 @@ on_eventbox_style_button_press_event   (GtkWidget       *widget,
                                         GdkEventButton  *event,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_eventbox_style_button_press_event\n");
+#endif
+
     gint new_style = -1;
 
     if(event->type != GDK_BUTTON_PRESS)
@@ -829,6 +1065,10 @@ on_eventbox_boost_button_press_event   (GtkWidget       *widget,
                                         GdkEventButton  *event,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_eventbox_boost_button_press_event\n");
+#endif
+
     gint new_boost = -1; 
 
     if(event->type != GDK_BUTTON_PRESS)
@@ -863,6 +1103,10 @@ void
 on_menu_show_finances_activate         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_show_finances_activate\n");
+#endif
+
     if(sett_int("int_opt_disable_finances"))
     {
 	game_gui_print_message(_("Finances are disabled in this country definition."));
@@ -882,6 +1126,10 @@ void
 on_menu_show_stadium_activate          (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_show_stadium_activate\n");
+#endif
+
     if(sett_int("int_opt_disable_stadium"))
     {
 	game_gui_print_message(
@@ -897,6 +1145,10 @@ on_menu_check_button_press_event       (GtkWidget       *widget,
                                         GdkEventButton  *event,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_check_button_press_event\n");
+#endif
+
     game_gui_read_check_items(widget);
 
     setsav0;
@@ -908,6 +1160,10 @@ void
 on_menu_offer_new_contract_activate    (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_offer_new_contract_activate\n");
+#endif
+
     if(sett_int("int_opt_disable_contracts"))
     {
 	game_gui_print_message(_("Contracts are disabled in this country definition."));
@@ -930,6 +1186,10 @@ void
 on_menu_show_info_activate      (GtkMenuItem     *menuitem,
 				 gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_show_info_activate\n");
+#endif
+
     if(selected_row == -1)
     {
 	game_gui_print_message(_("You haven't selected a player."));
@@ -949,6 +1209,10 @@ on_player_menu_put_on_transfer_list_activate
                                         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_player_menu_put_on_transfer_list_activate\n");
+#endif
+
     on_menu_put_on_transfer_list_activate(NULL, NULL);
 }
 
@@ -958,6 +1222,10 @@ on_player_menu_remove_from_transfer_list_activate
                                         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_player_menu_remove_from_transfer_list_activate\n");
+#endif
+
     on_menu_remove_from_transfer_list_activate(NULL, NULL);
 }
 
@@ -967,6 +1235,10 @@ on_player_menu_offer_new_contract_activate
                                         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_player_menu_offer_new_contract_activate\n");
+#endif
+
     on_menu_offer_new_contract_activate(NULL, NULL);
 }
 
@@ -975,6 +1247,10 @@ void
 on_player_menu_fire_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_player_menu_fire_activate\n");
+#endif
+
     on_menu_fire_activate(NULL, NULL);
 }
 
@@ -984,6 +1260,10 @@ on_player_menu_shoots_penalties_activate
                                         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_player_menu_shoots_penalties_activate\n");
+#endif
+
     on_menu_shoots_penalties_activate(NULL, NULL);
 }
 
@@ -992,6 +1272,10 @@ on_player_menu_move_to_youth_academy_activate
                                         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_player_menu_move_to_youth_academy_activate\n");
+#endif
+
     on_menu_move_to_youth_academy_activate(NULL, NULL);
 }
 
@@ -1000,6 +1284,10 @@ void
 on_menu_browse_players_activate        (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_browse_players_activate\n");
+#endif
+
     stat0 = STATUS_SHOW_PLAYER_LIST;
     callback_show_player_list(SHOW_CURRENT);
 
@@ -1010,6 +1298,10 @@ void
 on_player_menu_show_info_activate      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_player_menu_show_info_activate\n");
+#endif
+
     on_menu_show_info_activate(NULL, NULL);
 }
 
@@ -1018,6 +1310,10 @@ void
 on_menu_rearrange_team_activate        (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_rearrange_team_activate\n");
+#endif
+
     team_rearrange(current_user.tm);
     treeview_show_user_player_list();
 }
@@ -1027,6 +1323,10 @@ void
 on_menu_load_last_save_activate        (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_load_last_save_activate\n");
+#endif
+
     if(load_save_load_game("last_save", FALSE))
     {
 	cur_user = 0;
@@ -1039,6 +1339,10 @@ void
 on_menu_user_show_history_activate     (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_user_show_history_activate\n");
+#endif
+
     stat0 = STATUS_SHOW_USER_HISTORY;
     treeview_show_user_history();
 
@@ -1049,6 +1353,10 @@ void
 on_button_reset_players_clicked        (GtkButton       *button,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_button_reset_players_clicked\n");
+#endif
+
     on_menu_reset_players_activate(NULL, NULL);
 }
 
@@ -1057,6 +1365,10 @@ void
 on_menu_reset_players_activate         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_reset_players_activate\n");
+#endif
+
     gint idx = -1;
 
     if(team_is_user(usr(stat2).live_game.fix->teams[0]) == -1 ||
@@ -1078,6 +1390,10 @@ on_button_quit_button_press_event      (GtkWidget       *widget,
                                         GdkEventButton  *event,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_button_quit_button_press_event\n");
+#endif
+
     if(event->button == 3 && counters[COUNT_SHOW_DEBUG] == 0)
     {
 	counters[COUNT_SHOW_DEBUG] = 1;
@@ -1097,6 +1413,10 @@ void
 on_menu_show_youth_academy_activate    (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_show_youth_academy_activate\n");
+#endif
+
     if(sett_int("int_opt_disable_ya"))
     {
 	game_gui_print_message(
@@ -1112,6 +1432,10 @@ void
 on_menu_set_investment_activate        (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_set_investment_activate\n");
+#endif
+
     if(sett_int("int_opt_disable_ya"))
     {
 	game_gui_print_message(
@@ -1122,13 +1446,17 @@ on_menu_set_investment_activate        (GtkMenuItem     *menuitem,
     stat1 = STATUS_SET_YA_PERCENTAGE;
     window_show_digits(
 	_("Set the percentage of your income you want to devote to your youth academy."),
-	NULL, -1, "%", current_user.youth_academy.percentage);
+	NULL, -1, "%", current_user.youth_academy.percentage, FALSE);
 }
 
 void
 on_menu_youth_move_to_team_activate    (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_youth_move_to_team_activate\n");
+#endif
+
     if(sett_int("int_opt_disable_ya"))
     {
 	game_gui_print_message(
@@ -1154,6 +1482,10 @@ on_menu_youth_kick_out_of_academy_activate
                                         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_youth_kick_out_of_academy_activate\n");
+#endif
+
     if(opt_user_int("int_opt_user_confirm_youth"))
     {
 	stat1 = STATUS_QUERY_KICK_YOUTH;
@@ -1172,6 +1504,10 @@ void
 on_mm_add_last_match_activate          (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_mm_add_last_match_activate\n");
+#endif
+
     if(current_user.live_game.units->len == 0)
     {
 	game_gui_show_warning(_("No match stored."));
@@ -1192,6 +1528,10 @@ void
 on_mm_manage_matches_activate          (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_mm_manage_matches_activate\n");
+#endif
+
     if(current_user.mmatches_file == NULL)
     {
 	stat5 = STATUS_SELECT_MM_FILE_LOAD;
@@ -1205,6 +1545,10 @@ void
 on_menu_save_window_geometry_activate  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_save_window_geometry_activate\n");
+#endif
+
     window_main_save_geometry();
 }
 
@@ -1212,6 +1556,10 @@ void
 on_menu_betting_activate               (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_betting_activate\n");
+#endif
+
     on_button_back_to_main_clicked(NULL, NULL);
     window_show_bets();
 }
@@ -1220,6 +1568,10 @@ void
 on_menu_show_job_exchange_activate     (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_menu_show_job_exchange_activate\n");
+#endif
+
     stat0 = STATUS_SHOW_JOB_EXCHANGE;
 
     gui_set_arrows();
@@ -1238,8 +1590,82 @@ on_hpaned2_button_release_event        (GtkWidget       *widget,
                                         GdkEventButton  *event,
                                         gpointer         user_data)
 {
+#ifdef DEBUG
+    printf("on_hpaned2_button_release_event\n");
+#endif
+
     window.paned_pos = 
 	gtk_paned_get_position(GTK_PANED(widget));
 
     return FALSE;
 }
+
+void
+on_training_camp_activate              (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+#ifdef DEBUG
+    printf("on_training_camp_activate\n");
+#endif
+
+   if(sett_int("int_opt_disable_training_camp"))
+    {
+	game_gui_print_message(
+	    _("Training camp is disabled in this country definition."));
+	return;
+    }
+
+   if(current_user.counters[COUNT_USER_TRAININGS_WEEK] == 
+      const_int("int_training_camps_week"))
+   {
+       game_gui_print_message(_("Your team has already had enough training camps this week."));
+       return;
+   }
+
+   if(current_user.counters[COUNT_USER_TRAININGS_LEFT_SEASON] == 0)
+   {
+       game_gui_print_message(_("You've reached the limit of %d training camps for the season."),
+			      const_int("int_training_camps_per_season"));
+       return;
+   }
+
+   window_show_training_camp();
+}
+
+void
+on_automatic_loan_repayment_activate   (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+#ifdef DEBUG
+    printf("on_automatic_loan_repayment_activate\n");
+#endif
+
+    if(sett_int("int_opt_disable_finances"))
+    {
+	game_gui_print_message(_("Finances are disabled in this country definition."));
+	return;
+    }
+
+    if(current_user.debt == 0)
+    {
+        game_gui_print_message(_("You are not in debt."));
+        return;
+    }
+    else if(week >= fixture_get_last_scheduled_week() - 1)
+    {
+        game_gui_print_message(_("It's too late in the season for automatic loan repayment."));
+        return;            
+    }
+    
+    window_show_alr();
+}
+
+void
+on_menu_news_activate                  (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+    window_create(WINDOW_NEWS);
+    treeview2_show_news();
+    counters[COUNT_NEWS_SHOWN] = 1;
+}
+
