@@ -26,6 +26,7 @@
 #include "bet_struct.h"
 #include "free.h"
 #include "lg_commentary_struct.h"
+#include "news_struct.h"
 #include "strategy_struct.h"
 #include "transfer.h"
 #include "user.h"
@@ -38,6 +39,10 @@
 void
 free_memory(void)
 {
+#ifdef DEBUG
+    printf("free_memory\n");
+#endif
+
     free_variables();
     free_names(FALSE);
     free_transfer_list();
@@ -45,16 +50,23 @@ free_memory(void)
     free_country(&country, FALSE);
     free_users(FALSE);
     free_bets(FALSE);
-    free_live_game(&live_game_temp);
     free_lg_commentary(FALSE);
+    free_news(FALSE);
+    free_newspaper(FALSE);
     free_support_dirs();
     free_jobs(FALSE);
+
+    free_g_array(&live_games);
 }
 
 /** Free the transfer list. */
 void
 free_transfer_list(void)
 {
+#ifdef DEBUG
+    printf("free_transfer_list\n");
+#endif
+
     gint i;
 
     for(i=0;i<transfer_list->len;i++)
@@ -67,6 +79,10 @@ free_transfer_list(void)
 void
 free_season_stats(gboolean reset)
 {
+#ifdef DEBUG
+    printf("free_season_stats\n");
+#endif
+
     gint i, j;
 
     if(season_stats == NULL)
@@ -121,6 +137,10 @@ free_season_stats(gboolean reset)
 void
 free_users(gboolean reset)
 {
+#ifdef DEBUG
+    printf("free_users\n");
+#endif
+
     gint i;
 
     if(users == NULL)
@@ -144,6 +164,10 @@ free_users(gboolean reset)
 void
 free_user(User *user)
 {
+#ifdef DEBUG
+    printf("free_user\n");
+#endif
+
     gint i, j;
 
     free_gchar_ptr(user->name);
@@ -180,6 +204,10 @@ free_user(User *user)
 void
 free_mmatches(GArray **mmatches, gboolean reset)
 {
+#ifdef DEBUG
+    printf("free_mmatches\n");
+#endif
+
     gint i;
 
     if(*mmatches == NULL)
@@ -205,6 +233,10 @@ free_mmatches(GArray **mmatches, gboolean reset)
 void
 free_event(Event *event)
 {
+#ifdef DEBUG
+    printf("free_event\n");
+#endif
+
     free_gchar_ptr(event->value_string);
 }
 
@@ -215,6 +247,10 @@ free_event(Event *event)
 void
 free_option_list(OptionList *optionlist, gboolean reset)
 {
+#ifdef DEBUG
+    printf("free_option_list\n");
+#endif
+
     gint i;
 
     if(optionlist->list == NULL)
@@ -247,6 +283,10 @@ free_option_list(OptionList *optionlist, gboolean reset)
 void
 free_live_game(LiveGame *match)
 {
+#ifdef DEBUG
+    printf("free_live_game\n");
+#endif
+
     gint i, j, k;
 
     if(match->units == NULL || match->started_game == -1)
@@ -278,6 +318,10 @@ free_live_game(LiveGame *match)
 void
 free_country(Country *cntry, gboolean reset)
 {
+#ifdef DEBUG
+    printf("free_country\n");
+#endif
+
     free_gchar_ptr(cntry->name);
     free_gchar_ptr(cntry->symbol);
     free_gchar_ptr(cntry->sid);
@@ -287,7 +331,10 @@ free_country(Country *cntry, gboolean reset)
     free_g_ptr_array(&cntry->allcups);
 
     if(reset)
+    {
 	cntry->allcups = g_ptr_array_new();
+	cntry->sid = g_strdup("NONAME");
+    }
 }
 
 /**
@@ -297,6 +344,10 @@ free_country(Country *cntry, gboolean reset)
 void
 free_leagues_array(GArray **leagues, gboolean reset)
 {
+#ifdef DEBUG
+    printf("free_leagues_array\n");
+#endif
+
     gint i;
 
     if(*leagues == NULL)
@@ -322,30 +373,83 @@ free_leagues_array(GArray **leagues, gboolean reset)
 void
 free_league(League *league)
 {
+#ifdef DEBUG
+    printf("free_league\n");
+#endif
+
     free_gchar_ptr(league->name);
     free_gchar_ptr(league->short_name);
     free_gchar_ptr(league->symbol);
     free_gchar_ptr(league->sid);
-    free_gchar_ptr(league->prom_rel.prom_games_dest_sid);
-    free_gchar_ptr(league->prom_rel.prom_games_cup_sid);
  
+    free_gchar_array(&league->skip_weeks_with);
+
     if(league->teams != NULL)
 	free_teams_array(&league->teams, FALSE);
 
+    free_joined_leagues(&league->joined_leagues);
+    free_prom_rel(&league->prom_rel);
+
     free_g_array(&league->teams);
-    free_g_array(&league->prom_rel.elements);;
     
-    free_table(&league->table);
+    free_tables(&league->tables);
+    free_new_tables(&league->new_tables);
 
     free_g_array(&league->fixtures);
+    free_g_array(&league->rr_breaks);
+    free_g_array(&league->week_breaks);
+
+    free_g_array(&league->two_match_weeks[0]);
+    free_g_array(&league->two_match_weeks[1]);
 
     free_league_stats(&league->stats);
 }
 
+/** Free the promotion/relegation struct of a league. */
+void
+free_prom_rel(PromRel *prom_rel)
+{
+    gint i;
+
+    for(i = 0; i < prom_rel->elements->len; i++)
+        g_free(g_array_index(prom_rel->elements, PromRelElement, i).dest_sid);
+
+    free_g_array(&prom_rel->elements);
+
+    for(i = 0; i < prom_rel->prom_games->len; i++)
+    {
+        g_free(g_array_index(prom_rel->prom_games, PromGames, i).dest_sid);
+        g_free(g_array_index(prom_rel->prom_games, PromGames, i).loser_sid);
+        g_free(g_array_index(prom_rel->prom_games, PromGames, i).cup_sid);
+    }
+
+    free_g_array(&prom_rel->prom_games);
+}
+
+/** Free the data in the joined leagues array. */
+void
+free_joined_leagues(GArray **joined_leagues)
+{
+#ifdef DEBUG
+    printf("free_joined_leagues\n");
+#endif
+
+    gint i;
+
+    for(i = 0; i < (*joined_leagues)->len; i++)
+        free_gchar_ptr(g_array_index(*joined_leagues, JoinedLeague, i).sid);
+
+    free_g_array(joined_leagues);
+}
+
 /** Free the league stats. */
 void
 free_league_stats(LeagueStat *stats)
 {
+#ifdef DEBUG
+    printf("free_league_stats\n");
+#endif
+
     gint i;
 
     free_gchar_ptr(stats->league_name);
@@ -375,13 +479,41 @@ free_league_stats(LeagueStat *stats)
 }
 
 
-/** Free a table. */
+/** Free a tables array. */
 void
-free_table(Table *table)
+free_tables(GArray **tables)
 {
-    free_gchar_ptr(table->name);
+#ifdef DEBUG
+    printf("free_tables\n");
+#endif
 
-    free_g_array(&table->elements);
+    gint i;
+
+    for(i = 0; i < (*tables)->len; i++)
+    {
+        free_gchar_ptr(g_array_index(*tables, Table, i).name);        
+        free_g_array(&g_array_index(*tables, Table, i).elements);
+    }
+
+    g_array_free(*tables, TRUE);
+    *tables = NULL;
+}
+
+/** Free a new_tables array. */
+void
+free_new_tables(GArray **new_tables)
+{
+#ifdef DEBUG
+    printf("free_new_tables\n");
+#endif
+
+    gint i;
+
+    for(i = 0; i < (*new_tables)->len; i++)
+        free_gchar_ptr(g_array_index(*new_tables, NewTable, i).name);        
+
+    g_array_free(*new_tables, TRUE);
+    *new_tables = NULL;
 }
 
 /** Free the memory occupied by a teams array.
@@ -389,6 +521,10 @@ free_table(Table *table)
 void
 free_teams_array(GArray **teams, gboolean reset)
 {
+#ifdef DEBUG
+    printf("free_teams_array\n");
+#endif
+
     gint i;
 
     if(*teams == NULL)
@@ -414,6 +550,10 @@ free_teams_array(GArray **teams, gboolean reset)
 void
 free_team(Team *tm)
 {
+#ifdef DEBUG
+    printf("free_team\n");
+#endif
+
     free_gchar_ptr(tm->stadium.name);
     free_gchar_ptr(tm->name);
     free_gchar_ptr(tm->names_file);
@@ -427,6 +567,10 @@ free_team(Team *tm)
 void
 free_player_array(GArray **players)
 {
+#ifdef DEBUG
+    printf("free_player_array\n");
+#endif
+
     gint i;
 
     if(*players != NULL)
@@ -443,6 +587,10 @@ free_player_array(GArray **players)
 void
 free_player(Player *pl)
 {
+#ifdef DEBUG
+    printf("free_player\n");
+#endif
+
     free_gchar_ptr(pl->name);
 
     free_g_array(&pl->cards);
@@ -456,6 +604,10 @@ free_player(Player *pl)
 void
 free_cups_array(GArray **cups, gboolean reset)
 {
+#ifdef DEBUG
+    printf("free_cups_array\n");
+#endif
+
     gint i;
 
     if(*cups == NULL)
@@ -481,30 +633,25 @@ free_cups_array(GArray **cups, gboolean reset)
 void
 free_cup(Cup *cup)
 {
-    gint i, j;
+#ifdef DEBUG
+    printf("free_cup\n");
+#endif
+
+    gint i;
 
     free_gchar_ptr(cup->name);
     free_gchar_ptr(cup->short_name);
     free_gchar_ptr(cup->symbol);
     free_gchar_ptr(cup->sid);
 
+    free_gchar_array(&cup->skip_weeks_with);
+
     for(i=0;i<cup->rounds->len;i++)
-	if(g_array_index(cup->rounds, CupRound, i).round_robin_number_of_groups > 0)
-	{
-	    for(j=0;j<g_array_index(cup->rounds, CupRound, i).tables->len;j++)
-		free_table(&g_array_index(g_array_index(cup->rounds, CupRound, i).tables, Table, j));
-
-	    for(j=0;j<g_array_index(cup->rounds, CupRound, i).choose_teams->len;j++)
-		free_cup_choose_team(
-		    &g_array_index(g_array_index(cup->rounds, CupRound, i).choose_teams, CupChooseTeam, j));
-	    
-	    free_g_array(&g_array_index(cup->rounds, CupRound, i).choose_teams);
-	    free_teams_array(&g_array_index(cup->rounds, CupRound, i).teams, FALSE);
-	    g_ptr_array_free(g_array_index(cup->rounds, CupRound, i).team_ptrs, TRUE);
-	}
-
+        free_cup_round(&g_array_index(cup->rounds, CupRound, i));
     free_g_array(&cup->rounds);
+
     free_g_array(&cup->fixtures);
+    free_g_array(&cup->week_breaks);
 
     free_g_ptr_array(&cup->bye);
     free_gchar_array(&cup->team_names);
@@ -512,6 +659,39 @@ free_cup(Cup *cup)
     free_gchar_array(&cup->properties);
 }
 
+void
+free_cup_round(CupRound *cup_round)
+{
+#ifdef DEBUG
+    printf("free_cup_round\n");
+#endif
+
+    gint j;
+
+    g_free(cup_round->name);
+
+    free_g_array(&cup_round->two_match_weeks[0]);
+    free_g_array(&cup_round->two_match_weeks[1]);
+
+    for(j = 0; j < cup_round->waits->len; j++)
+        g_free(g_array_index(cup_round->waits, CupRoundWait, j).cup_sid);
+
+    free_g_array(&cup_round->waits);
+
+    if(cup_round->round_robin_number_of_groups > 0)
+    {
+        free_tables(&cup_round->tables);
+
+        for(j=0;j<cup_round->choose_teams->len;j++)
+            free_cup_choose_team(
+                &g_array_index(cup_round->choose_teams, CupChooseTeam, j));
+	    
+        free_g_array(&cup_round->choose_teams);
+        free_teams_array(&cup_round->teams, FALSE);
+        g_ptr_array_free(cup_round->team_ptrs, TRUE);
+    }    
+}
+
 /**
    Free the memory occupied by a CupChooseTeam.
    @param cup_choose_team The pointer to the team we free.
@@ -519,6 +699,10 @@ free_cup(Cup *cup)
 void
 free_cup_choose_team(CupChooseTeam *cup_choose_team)
 {
+#ifdef DEBUG
+    printf("free_cup_choose_team\n");
+#endif
+
     free_gchar_ptr(cup_choose_team->sid);
 }
 
@@ -526,6 +710,10 @@ free_cup_choose_team(CupChooseTeam *cup_choose_team)
 void
 free_variables(void)
 {
+#ifdef DEBUG
+    printf("free_variables\n");
+#endif
+
     free_option_list(&options, FALSE);
     free_option_list(&settings, FALSE);
     free_option_list(&constants, FALSE);
@@ -543,6 +731,10 @@ free_variables(void)
 void
 free_lg_commentary(gboolean reset)
 {
+#ifdef DEBUG
+    printf("free_lg_commentary\n");
+#endif
+
     gint i, j;
 
     for(i=0;i<LIVE_GAME_EVENT_END;i++)
@@ -562,6 +754,70 @@ free_lg_commentary(gboolean reset)
 	    lg_commentary[i] = g_array_new(FALSE, FALSE, sizeof(LGCommentary));
 }
 
+/** Free the news variables. */
+void
+free_news(gboolean reset)
+{
+#ifdef DEBUG
+    printf("free_news\n");
+#endif
+
+    gint i, j, k;
+
+    for(i=0;i<NEWS_ARTICLE_TYPE_END;i++)
+	if(news[i] != NULL)
+	{
+	    for(j=0;j<news[i]->len;j++)
+	    {
+		g_free(g_array_index(news[i], NewsArticle, j).condition);
+                
+                for(k = 0; k < g_array_index(news[i], NewsArticle, j).titles->len; k++)
+                {
+                    g_free(g_array_index(g_array_index(news[i], NewsArticle, j).titles, NewsText, k).text);
+                    g_free(g_array_index(g_array_index(news[i], NewsArticle, j).titles, NewsText, k).condition);
+                }
+
+                g_array_free(g_array_index(news[i], NewsArticle, j).titles, TRUE);
+
+                for(k = 0; k < g_array_index(news[i], NewsArticle, j).subtitles->len; k++)
+                {
+                    g_free(g_array_index(g_array_index(news[i], NewsArticle, j).subtitles, NewsText, k).text);
+                    g_free(g_array_index(g_array_index(news[i], NewsArticle, j).subtitles, NewsText, k).condition);
+                }
+
+                g_array_free(g_array_index(news[i], NewsArticle, j).subtitles, TRUE);
+	    }
+
+	    free_g_array(&news[i]);
+	}
+
+    if(reset)
+	for(i=0;i<NEWS_ARTICLE_TYPE_END;i++)
+	    news[i] = g_array_new(FALSE, FALSE, sizeof(NewsArticle));
+}
+
+void
+free_newspaper(gboolean reset)
+{
+    gint i;
+
+    for(i = 0; i < newspaper.articles->len; i++)
+        free_newspaper_article(&g_array_index(newspaper.articles, NewsPaperArticle, i));
+
+    g_array_free(newspaper.articles, TRUE);
+
+    if(reset)
+        newspaper.articles = g_array_new(FALSE, FALSE, sizeof(NewsPaperArticle));
+}
+
+void
+free_newspaper_article(NewsPaperArticle *article)
+{
+    g_free(article->title_small);
+    g_free(article->title);
+    g_free(article->subtitle);
+}
+
 /**
    Free a GPtrArray containing strings.
    @param array The array to be freed.
@@ -569,6 +825,14 @@ free_lg_commentary(gboolean reset)
 void
 free_gchar_array(GPtrArray **array)
 {
+#ifdef DEBUG
+    printf("_array\n");
+#endif
+
+#ifdef DEBUG
+    printf("free_gchar_array\n");
+#endif
+
     gint i;
 
     if(*array == NULL)
@@ -586,6 +850,10 @@ free_gchar_array(GPtrArray **array)
 void
 free_g_string(GString **string)
 {
+#ifdef DEBUG
+    printf("free_g_string\n");
+#endif
+
     if(*string == NULL)
 	return;
 
@@ -599,6 +867,10 @@ free_g_string(GString **string)
 void
 free_g_array(GArray **array)
 {
+#ifdef DEBUG
+    printf("free_g_array\n");
+#endif
+
     if(*array == NULL)
 	return;
 
@@ -612,6 +884,10 @@ free_g_array(GArray **array)
 void
 free_g_ptr_array(GPtrArray **array)
 {
+#ifdef DEBUG
+    printf("free_g_ptr_array\n");
+#endif
+
     if(*array == NULL)
 	return;
 
@@ -624,6 +900,10 @@ free_g_ptr_array(GPtrArray **array)
 void
 free_support_dirs(void)
 {
+#ifdef DEBUG
+    printf("free_support_dirs\n");
+#endif
+
   GList *elem = support_directories;
 
   if(elem == NULL)
@@ -643,6 +923,10 @@ free_support_dirs(void)
 void
 free_name_list(NameList *namelist, gboolean reset)
 {
+#ifdef DEBUG
+    printf("free_name_list\n");
+#endif
+
     gint i;
 
     if(namelist->sid == NULL)
@@ -679,6 +963,10 @@ free_name_list(NameList *namelist, gboolean reset)
 void
 free_names(gboolean reset)
 {
+#ifdef DEBUG
+    printf("free_names\n");
+#endif
+
     gint i;
 
     if(name_lists == NULL)
@@ -702,6 +990,10 @@ free_names(gboolean reset)
 void
 free_strategies(void)
 {
+#ifdef DEBUG
+    printf("free_strategies\n");
+#endif
+
     gint i, j;
 
     for(i=0;i<strategies->len;i++)
@@ -743,6 +1035,10 @@ free_strategies(void)
 void
 free_bets(gboolean reset)
 {
+#ifdef DEBUG
+    printf("free_bets\n");
+#endif
+
     free_g_array(&(bets[0]));
     free_g_array(&(bets[1]));
 
@@ -759,6 +1055,10 @@ free_bets(gboolean reset)
 void
 free_job(Job *job, gboolean free_tm)
 {
+#ifdef DEBUG
+    printf("free_job\n");
+#endif
+
     gint i;
 
     if(job->type == JOB_TYPE_INTERNATIONAL)
@@ -781,6 +1081,10 @@ free_job(Job *job, gboolean free_tm)
 void
 free_jobs(gboolean reset)
 {
+#ifdef DEBUG
+    printf("free_jobs\n");
+#endif
+
     gint i;
 
     if(jobs == NULL)
