@@ -1,26 +1,26 @@
 /*
-   game.c
+  game.c
 
-   Bygfoot Football Manager -- a small and simple GTK2-based
-   football management game.
+  Bygfoot Football Manager -- a small and simple GTK2-based
+  football management game.
 
-   http://bygfoot.sourceforge.net
+  http://bygfoot.sourceforge.net
 
-   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+  Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License
-   as published by the Free Software Foundation; either version 2
-   of the License, or (at your option) any later version.
+  This program is free software; you can redistribute it and/or
+  modify it under the terms of the GNU General Public License
+  as published by the Free Software Foundation; either version 2
+  of the License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 #include "cup.h"
@@ -52,6 +52,10 @@ void
 game_get_values(const Fixture *fix, gfloat team_values[][GAME_TEAM_VALUE_END],
 		gfloat home_advantage)
 {
+#ifdef DEBUG
+    printf("game_get_values\n");
+#endif
+
     gint i, j;
     Team *tm[2] = {fix->teams[0], fix->teams[1]};
     gfloat style_factor;
@@ -64,7 +68,7 @@ game_get_values(const Fixture *fix, gfloat team_values[][GAME_TEAM_VALUE_END],
 	style_factor = (gfloat)tm[i]->style * const_float("float_game_style_factor");
 
 	team_values[i][GAME_TEAM_VALUE_GOALIE] = 
-	    game_get_player_contribution(player_of_idx_team(tm[i], 0), FALSE, TRUE) * 
+	    player_get_game_skill(player_of_idx_team(tm[i], 0), FALSE, TRUE) * 
 	    (1 + home_advantage * (i == 0));
 
 	for(j=1;j<11;j++)
@@ -100,6 +104,7 @@ game_get_values(const Fixture *fix, gfloat team_values[][GAME_TEAM_VALUE_END],
 gfloat
 game_get_player_contribution(const Player *pl, gint type, gboolean special)
 {
+
 /** How the cskill of field players get weighted for the team values in
     a match. Rows are player position, columns value type. 
     @see game_get_player_contribution() */
@@ -132,6 +137,10 @@ game_get_player(const Team *tm, gint player_type,
 		gint last_penalty, gint not_this_one,
 		gboolean skills)
 {
+#ifdef DEBUG
+    printf("game_get_player\n");
+#endif
+
     gint i, player = not_this_one;
     gfloat weights[3];
     gfloat probs[10];
@@ -186,7 +195,7 @@ game_get_player(const Team *tm, gint player_type,
 	    if(i < 10)
 		g_print("prob %.3f  ", probs[i]);
 	    g_print("%d %20s health %d cskill %.2f\n", i, player_of_idx_team(tm, i)->name,
-		   player_of_idx_team(tm, i)->health, player_of_idx_team(tm, i)->cskill);
+		    player_of_idx_team(tm, i)->health, player_of_idx_team(tm, i)->cskill);
 	}
 
 	main_exit_program(EXIT_INT_NOT_FOUND, NULL);
@@ -206,6 +215,10 @@ game_get_player(const Team *tm, gint player_type,
 void
 game_get_player_probs(GArray *players, gfloat *probs, gfloat *weights, gboolean skills)
 {
+#ifdef DEBUG
+    printf("game_get_player_probs\n");
+#endif
+
     gint i;
 
     probs[0] = (skills) ? 
@@ -239,6 +252,10 @@ game_get_player_probs(GArray *players, gfloat *probs, gfloat *weights, gboolean
 gint
 game_get_penalty_taker(const Team *tm, gint last_penalty)
 {
+#ifdef DEBUG
+    printf("game_get_penalty_taker\n");
+#endif
+
     gint i, return_value = -1;
     GPtrArray *players = g_ptr_array_new();
 
@@ -271,44 +288,20 @@ game_get_penalty_taker(const Team *tm, gint last_penalty)
 void
 game_initialize(Fixture *fix)
 {
+#ifdef DEBUG
+    printf("game_initialize\n");
+#endif
+
     gint i, j;
-    gfloat journey_factor =
-	(fix->clid < ID_CUP_START ||
-	 (fix->clid >= ID_CUP_START && 
-	  query_cup_is_national(fix->clid))) ?
-	const_float("float_game_finance_journey_factor_national") :
-	const_float("float_game_finance_journey_factor_international");    
     gint user_idx[2] = {team_is_user(fix->teams[0]), team_is_user(fix->teams[1])};
-    gint ticket_income = 0;
 
     if(fix->home_advantage)
 	game_assign_attendance(fix);
     else
 	game_assign_attendance_neutral(fix);
 
-    ticket_income = 
-	fix->attendance * const_int("int_team_stadium_ticket_price");
-
-    if(!sett_int("int_opt_disable_finances") && user_idx[0] != -1 && fix->home_advantage)
-    {
-	usr(user_idx[0]).money += ticket_income;
-	usr(user_idx[0]).money_in[1][MON_IN_TICKET] += ticket_income;
-
-	usr(user_idx[0]).money -= 
-	    (gint)rint((gfloat)ticket_income *
-		       (gfloat)usr(user_idx[0]).youth_academy.percentage / 100);
-	usr(user_idx[0]).money_out[1][MON_OUT_YA] -= 
-	    (gint)rint((gfloat)ticket_income *
-		       (gfloat)usr(user_idx[0]).youth_academy.percentage / 100);
-
-	if(debug < 50)
-	{
-	    fix->teams[0]->stadium.safety -= 
-		math_rnd(const_float("float_game_stadium_safety_deterioration_lower"),
-			 const_float("float_game_stadium_safety_deterioration_upper"));
-	    fix->teams[0]->stadium.safety = CLAMP(fix->teams[0]->stadium.safety, 0, 1);
-	}
-    }
+    if(!sett_int("int_opt_disable_finances"))
+	finance_assign_game_money(fix);
 
     for(i=0;i<2;i++)
     {
@@ -345,19 +338,6 @@ game_initialize(Fixture *fix)
 
 	if(user_idx[i] != -1)
 	{
-	    if(i == 1 || !fix->home_advantage)
-	    {
-		usr(user_idx[i]).money_out[1][MON_OUT_JOURNEY] -= 
-		    (gint)(finance_wage_unit(fix->teams[i]) * journey_factor);
-		usr(user_idx[i]).money -= (gint)(finance_wage_unit(fix->teams[i]) * journey_factor);
-	    }
-
-	    if(!fix->home_advantage)
-	    {
-		usr(user_idx[i]).money_in[1][MON_IN_TICKET] += (gint)rint((gfloat)ticket_income / 2);
-		usr(user_idx[i]).money += (gint)rint((gfloat)ticket_income / 2);
-	    }
-
 	    usr(user_idx[i]).counters[COUNT_USER_SHOW_RES] = 1;
 	}
     }
@@ -369,6 +349,10 @@ game_initialize(Fixture *fix)
 void
 game_assign_attendance(Fixture *fix)
 {
+#ifdef DEBUG
+    printf("game_assign_attendance\n");
+#endif
+
     Team *tm[2] = {fix->teams[0], fix->teams[1]};
     gfloat factor = 
 	math_rnd(const_float("float_game_stadium_attendance_percentage_lower"),
@@ -391,13 +375,17 @@ game_assign_attendance(Fixture *fix)
 	if(cup_from_clid(fix->clid)->rounds->len - fix->round <=
 	   const_int("int_game_stadium_attendance_cup_rounds_full_house"))
 	    factor = 1;
-	else if(query_cup_is_national(fix->clid))
+	else if(query_league_cup_has_property(fix->clid, "national"))
 	    factor *= const_float("float_game_stadium_attendance_cup_national_factor");
 	else
 	    factor *= const_float("float_game_stadium_attendance_cup_international_factor");
     }
 
-    factor = MIN(factor, 1);
+    /* calculate the differnce in ticket prices has on attendance */
+    gfloat delta_price = tm[0]->stadium.ticket_price - const_int("int_team_stadium_ticket_price");
+    gfloat price_factor = math_gauss_dist(0.92, 1.08) * 1/(1+const_float("float_team_stadium_price_attendance_factor")*delta_price);
+
+    factor = MIN(factor * price_factor, 1);
     fix->attendance = MIN(MIN((gint)rint((gfloat)tm[0]->stadium.capacity * factor),
 			      max_att * factor), max_att);
 
@@ -412,10 +400,14 @@ game_assign_attendance(Fixture *fix)
 void
 game_assign_attendance_neutral(Fixture *fix)
 {
+#ifdef DEBUG
+    printf("game_assign_attendance_neutral\n");
+#endif
+
     const GPtrArray *teamsp = 
 	(GPtrArray*)league_cup_get_teams(fix->clid);
     gfloat av_att = (fix->clid >= ID_CUP_START && 
-		     query_cup_is_international(fix->clid) && teamsp->len > 0) ?
+		     query_league_cup_has_property(fix->clid, "international") && teamsp->len > 0) ?
 	(gfloat)league_cup_average_capacity(fix->clid) :
 	(gfloat)league_cup_average_capacity(lig(0).id);
 
@@ -429,6 +421,10 @@ game_assign_attendance_neutral(Fixture *fix)
 void
 game_save_team_states(void)
 {
+#ifdef DEBUG
+    printf("game_save_team_states\n");
+#endif
+
     gint i, j;
     const Team *teams[2] = {usr(stat2).live_game.fix->teams[0], 
 			    usr(stat2).live_game.fix->teams[1]};
@@ -454,6 +450,10 @@ game_save_team_states(void)
 gboolean
 game_check_live_game_resume_state(void)
 {
+#ifdef DEBUG
+    printf("game_check_live_game_resume_state\n");
+#endif
+
     gint i, j;
     gint subs[2] = {0, 0};
     const Team *teams[2] = {usr(stat2).live_game.fix->teams[0], 
@@ -483,6 +483,10 @@ game_check_live_game_resume_state(void)
 void
 game_reset_players(gint idx)
 {
+#ifdef DEBUG
+    printf("game_reset_players\n");
+#endif
+
     gint i;
     Team *tm = usr(stat2).live_game.fix->teams[idx];
     GArray *players = g_array_new(FALSE, FALSE, sizeof(Player));
@@ -511,6 +515,10 @@ game_reset_players(gint idx)
 void
 game_get_subs(gint team_number, gint *subs_in, gint *subs_out)
 {
+#ifdef DEBUG
+    printf("game_get_subs\n");
+#endif
+
     gint i, cnt = 0;
     const Team *tm = usr(stat2).live_game.fix->teams[team_number];
     gint current_players[11];
@@ -545,6 +553,10 @@ game_get_subs(gint team_number, gint *subs_in, gint *subs_out)
 void
 game_player_injury(Player *pl)
 {
+#ifdef DEBUG
+    printf("game_player_injury\n");
+#endif
+
     gint i;
     gfloat rndom;
     /* probabilities of different injuries */
@@ -645,6 +657,10 @@ game_player_injury(Player *pl)
 gfloat
 game_get_foul_possession_factor(gint boost1, gint boost2)
 {
+#ifdef DEBUG
+    printf("game_get_foul_possession_factor\n");
+#endif
+
     if(boost1 == boost2)
 	return 1;
 
@@ -662,6 +678,10 @@ game_get_foul_possession_factor(gint boost1, gint boost2)
 gint
 game_substitute_player(Team *tm, gint player_number)
 {
+#ifdef DEBUG
+    printf("game_substitute_player\n");
+#endif
+
     gint i, substitute = -1;
     GPtrArray *substitutes = g_ptr_array_new();
     gboolean adapt_structure;
@@ -723,6 +743,10 @@ game_substitute_player(Team *tm, gint player_number)
 gint
 game_find_to_substitute(gint clid, const Team *tm)
 {
+#ifdef DEBUG
+    printf("game_find_to_substitute\n");
+#endif
+
     gint i;
     gint position_to_substitute = -1;    
     GPtrArray *players = g_ptr_array_new();
@@ -763,6 +787,10 @@ game_find_to_substitute(gint clid, const Team *tm)
 gint
 game_player_get_ban_duration(void)
 {
+#ifdef DEBUG
+    printf("game_player_get_ban_duration\n");
+#endif
+
     gint i;
     gfloat rndom;
     gfloat duration_probs[6] =
@@ -796,6 +824,10 @@ void
 game_substitute_player_send_off(gint clid, Team *tm, gint player_number, 
 				gint *to_substitute, gint *substitute)
 {
+#ifdef DEBUG
+    printf("game_substitute_player_send_off\n");
+#endif
+
     gint i;
     gint position = -1;
     GPtrArray *substitutes = NULL;
@@ -853,6 +885,10 @@ game_substitute_player_send_off(gint clid, Team *tm, gint player_number,
 void
 game_decrease_fitness(const Fixture *fix)
 {
+#ifdef DEBUG
+    printf("game_decrease_fitness\n");
+#endif
+
     gint i, j;
 
     for(i=0;i<2;i++)
@@ -870,6 +906,10 @@ game_decrease_fitness(const Fixture *fix)
 void
 game_update_stats(LiveGame *lg, const LiveGameUnit *unit)
 {
+#ifdef DEBUG
+    printf("game_update_stats\n");
+#endif
+
     gint i;
     LiveGameStats *stats = &lg->stats;
     
@@ -928,6 +968,10 @@ game_update_stats(LiveGame *lg, const LiveGameUnit *unit)
 void
 game_update_stats_player(LiveGame *lg, const LiveGameUnit *unit)
 {
+#ifdef DEBUG
+    printf("game_update_stats_player\n");
+#endif
+
     gint i;
     gchar buf[SMALL], buf2[SMALL];    
     LiveGameStats *stats = &lg->stats;
@@ -939,6 +983,7 @@ game_update_stats_player(LiveGame *lg, const LiveGameUnit *unit)
     const Team *tm[2] = {lg->fix->teams[0], 
 			 lg->fix->teams[1]};
     GPtrArray *players = NULL;
+    const gchar *player_name;
     
     if(unit->event.type == LIVE_GAME_EVENT_GOAL ||
        unit->event.type == LIVE_GAME_EVENT_OWN_GOAL)
@@ -953,29 +998,34 @@ game_update_stats_player(LiveGame *lg, const LiveGameUnit *unit)
 	    /* A goal scored with a free kick. */
 	    strcpy(buf2, _(" (FK)"));
 	else if(unit->event.type == LIVE_GAME_EVENT_OWN_GOAL)
+            /* An own goal */
 	    strcpy(buf2, _(" (OG)"));
 	else 
 	    strcpy(buf2, "");
 
-	for(i=0;i<stats->players[array_index][LIVE_GAME_STAT_ARRAY_SCORERS]->len;i++)
+        player_name = player_of_id_team(tm[team], player)->name;
+        if(!own_goal)
+            g_ptr_array_add(stats->players[array_index][LIVE_GAME_STAT_ARRAY_SCORERS], g_strdup(player_name));
+
+	for(i=0;i<stats->players[array_index][LIVE_GAME_STAT_ARRAY_SCORERS_FOR_DISPLAY]->len;i++)
 	{
 	    if(g_str_has_prefix((gchar*)g_ptr_array_index(
-				    stats->players[array_index][LIVE_GAME_STAT_ARRAY_SCORERS], i),
-				player_of_id_team(tm[team], player)->name))
+				    stats->players[array_index][LIVE_GAME_STAT_ARRAY_SCORERS_FOR_DISPLAY], i),
+				player_name))
 	    {
 		sprintf(buf, "%s %d%s",
 			(gchar*)g_ptr_array_index(
-			    stats->players[array_index][LIVE_GAME_STAT_ARRAY_SCORERS], i),
+			    stats->players[array_index][LIVE_GAME_STAT_ARRAY_SCORERS_FOR_DISPLAY], i),
 			minute, buf2);
 		misc_string_assign((gchar**)&g_ptr_array_index(
-				       stats->players[array_index][LIVE_GAME_STAT_ARRAY_SCORERS], i), buf);
+				       stats->players[array_index][LIVE_GAME_STAT_ARRAY_SCORERS_FOR_DISPLAY], i), buf);
 		return;
 	    }
 	}
     
-	sprintf(buf, "%s %d%s", player_of_id_team(tm[team], player)->name,
+	sprintf(buf, "%s %d%s", player_name,
 		minute, buf2);
-	g_ptr_array_add(stats->players[array_index][LIVE_GAME_STAT_ARRAY_SCORERS], g_strdup(buf));
+	g_ptr_array_add(stats->players[array_index][LIVE_GAME_STAT_ARRAY_SCORERS_FOR_DISPLAY], g_strdup(buf));
     }
     else
     {
@@ -1006,23 +1056,30 @@ game_update_stats_player(LiveGame *lg, const LiveGameUnit *unit)
 void
 game_post_match(Fixture *fix)
 {
+#ifdef DEBUG
+    printf("game_post_match\n");
+#endif
+
     gint i;
     GPtrArray *teams = NULL;
     Cup *cup = NULL;
     gchar buf[SMALL], buf2[SMALL];
+    gint usr_idx;
 
-    if((debug > 100 && fixture_user_team_involved(fix) != -1) ||
+    usr_idx = fixture_user_team_involved(fix);
+
+    if((debug > 100 && usr_idx != -1) ||
        debug > 130)
 	g_print("game_post_match: %s - %s\n", 
-	       fix->teams[0]->name,
-	       fix->teams[1]->name);
+		fix->teams[0]->name,
+		fix->teams[1]->name);
 
     if(query_fixture_has_tables(fix))
 	table_update(fix);
     
     for(i=0;i<2;i++)
 	team_update_post_match(fix->teams[i], fix);
-
+    
     if(fix->clid < ID_CUP_START)
 	return;
 
@@ -1055,17 +1112,17 @@ game_post_match(Fixture *fix)
 	}
 	g_ptr_array_free(teams, TRUE);
     }
-    else if(fixture_user_team_involved(fix) != -1)
+    else if(usr_idx != -1)
     {
 	cup_get_round_name(cup_from_clid(fix->clid), fix->round, buf);
 	sprintf(buf2, "%d", fix->round + 1);
 
-	user_history_add(&usr(fixture_user_team_involved(fix)),
+	user_history_add(&usr(usr_idx),
 			 USER_HISTORY_REACH_CUP_ROUND,
-			 usr(fixture_user_team_involved(fix)).tm->name,
+			 usr(usr_idx).tm->name,
 			 league_cup_get_name_string(fix->clid),
 			 buf, buf2);
-	user_add_cup_success(&usr(fixture_user_team_involved(fix)),
+	user_add_cup_success(&usr(usr_idx),
 			     cup, fix->round, USER_HISTORY_REACH_CUP_ROUND);
     }
 }
@@ -1076,6 +1133,10 @@ game_post_match(Fixture *fix)
 void
 game_stadium_event(Stadium *stadium, gint type)
 {
+#ifdef DEBUG
+    printf("game_stadium_event\n");
+#endif
+
     gfloat reduce;
     gfloat reduce_factor[3][2] =
 	{{const_float("float_game_stadium_safety_reduce_breakdown_lower"),
@@ -1099,6 +1160,10 @@ game_stadium_event(Stadium *stadium, gint type)
 void
 game_get_max_values(gfloat max_values[4])
 {
+#ifdef DEBUG
+    printf("game_get_max_values\n");
+#endif
+
     gint i, j;
     Player pl;
 
@@ -1125,6 +1190,10 @@ game_get_max_values(gfloat max_values[4])
 gint
 game_get_default_penalty_shooter(const Team *tm)
 {
+#ifdef DEBUG
+    printf("game_get_default_penalty_shooter\n");
+#endif
+
     gint return_value = -1;
 
     if(team_is_user(tm) != -1 &&
@@ -1149,6 +1218,10 @@ game_get_default_penalty_shooter(const Team *tm)
 void
 game_boost_cost(void)
 {
+#ifdef DEBUG
+    printf("game_boost_cost\n");
+#endif
+
     gfloat wage_unit = finance_wage_unit(usr(stat2).tm);
     gint deduce = 
 	(gint)rint(wage_unit * const_float("float_boost_cost_factor"));
