@@ -1,3 +1,28 @@
+/*
+   game.h
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #ifndef GAME_H
 #define GAME_H
 
@@ -21,7 +46,7 @@ game_get_values(const Fixture *fix, gfloat team_values[][GAME_TEAM_VALUE_END],
 		gfloat home_advantage);
 
 gfloat
-game_get_player_contribution(const Player *pl, gboolean attack);
+game_get_player_contribution(const Player *pl, gboolean attack, gboolean special);
 
 gint
 game_get_player(const Team *tm, gint player_type, 
@@ -68,10 +93,10 @@ gint
 game_player_get_ban_duration(void);
 
 void
-game_update_stats(gpointer live_game, gconstpointer live_game_unit);
+game_update_stats(LiveGame *lg, const LiveGameUnit *unit);
 
 void
-game_update_stats_player(gpointer live_game, gconstpointer live_game_unit);
+game_update_stats_player(LiveGame *lg, const LiveGameUnit *unit);
 
 void
 game_post_match(Fixture *fix);
@@ -94,4 +119,7 @@ game_reset_players(gint idx);
 gint
 game_get_default_penalty_shooter(const Team *tm);
 
+void
+game_boost_cost(void);
+
 #endif
