@@ -31,6 +31,7 @@
 #include "option_gui.h"
 #include "misc.h"
 #include "support.h"
+#include "training.h"
 #include "treeview.h"
 #include "user.h"
 #include "variables.h"
@@ -61,6 +62,10 @@ enum BooleanOptions
     BOOL_OPT_BET_SHOW_ALL_LEAGUES,
     BOOL_OPT_BET_SHOW_CUPS,
     BOOL_OPT_BET_SHOW_MY_RECENT,
+    BOOL_OPT_NEWS_USER,
+    BOOL_OPT_NEWS_CUP,
+    BOOL_OPT_NEWS_LEAGUE,
+    BOOL_OPT_NEWS_RECENT,
     BOOL_OPT_PL1_ATT_NAME,
     BOOL_OPT_PL1_ATT_CPOS,
     BOOL_OPT_PL1_ATT_POS,
@@ -105,6 +110,10 @@ enum BooleanOptions
 void
 option_gui_write_bool_widgets(gint **bool_options, GtkToggleButton **bool_widgets)
 {
+#ifdef DEBUG
+    printf("option_gui_write_bool_widgets\n");
+#endif
+
     bool_widgets[BOOL_OPT_CONF_QUIT] = 
 	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton_conf_quit"));
     bool_options[BOOL_OPT_CONF_QUIT] = opt_intp("int_opt_confirm_quit");
@@ -194,6 +203,22 @@ option_gui_write_bool_widgets(gint **bool_options, GtkToggleButton **bool_widget
 	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton_bet_show_only_recent"));
     bool_options[BOOL_OPT_BET_SHOW_MY_RECENT] = opt_user_intp("int_opt_user_bet_show_my_recent");
 
+    bool_widgets[BOOL_OPT_NEWS_USER] =
+	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton_news_user"));
+    bool_options[BOOL_OPT_NEWS_USER] = opt_intp("int_opt_news_create_user");
+
+    bool_widgets[BOOL_OPT_NEWS_CUP] =
+	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton_news_cup"));
+    bool_options[BOOL_OPT_NEWS_CUP] = opt_intp("int_opt_news_create_cup");
+
+    bool_widgets[BOOL_OPT_NEWS_LEAGUE] =
+	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton_news_league"));
+    bool_options[BOOL_OPT_NEWS_LEAGUE] = opt_intp("int_opt_news_create_league");
+
+    bool_widgets[BOOL_OPT_NEWS_RECENT] =
+	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton_news_recent"));
+    bool_options[BOOL_OPT_NEWS_RECENT] = opt_intp("int_opt_news_show_recent");
+
     bool_widgets[BOOL_OPT_PL1_ATT_NAME] =
 	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton1"));
     bool_options[BOOL_OPT_PL1_ATT_NAME] = opt_user_intp("int_opt_user_pl1_att_name");
@@ -350,6 +375,7 @@ enum SpinOptions
     SPIN_OPT_LIVE_VERBOSITY,
     SPIN_OPT_CONTRACT,
     SPIN_OPT_BET_WAGER,
+    SPIN_OPT_TRAINING_CAMP_RECREATION,
     SPIN_OPT_END
 };
 
@@ -357,6 +383,10 @@ enum SpinOptions
 void
 option_gui_write_spin_widgets(gint **spin_options, GtkSpinButton **spin_widgets)
 {
+#ifdef DEBUG
+    printf("option_gui_write_spin_widgets\n");
+#endif
+
     gint tmp = 0;
 
     spin_widgets[SPIN_OPT_AUTOSAVE] =
@@ -379,6 +409,10 @@ option_gui_write_spin_widgets(gint **spin_options, GtkSpinButton **spin_widgets)
 	GTK_SPIN_BUTTON(lookup_widget(window.options, "spinbutton_live_speed"));
     spin_options[SPIN_OPT_LIVE_SPEED] = opt_user_intp("int_opt_user_live_game_speed");
 
+    spin_widgets[SPIN_OPT_TRAINING_CAMP_RECREATION] =
+	GTK_SPIN_BUTTON(lookup_widget(window.options, "spinbutton_recreation"));
+    spin_options[SPIN_OPT_TRAINING_CAMP_RECREATION] = opt_user_intp("int_opt_user_training_camp_recreation");
+
     /** Note the spinbutton value so that it doesn't get lost
 	when setting the range. */    
     tmp = gtk_spin_button_get_value_as_int(spin_widgets[SPIN_OPT_LIVE_SPEED]);
@@ -409,7 +443,6 @@ option_gui_write_spin_widgets(gint **spin_options, GtkSpinButton **spin_widgets)
 			      (gdouble)tmp);
 }
 
-
 /** Text entries. */
 enum EntryOptions
 {
@@ -422,6 +455,10 @@ enum EntryOptions
 void
 option_gui_write_entry_widgets(gchar ***entry_options, GtkEntry **entry_widgets)
 {
+#ifdef DEBUG
+    printf("option_gui_write_entry_widgets\n");
+#endif
+
     entry_widgets[ENTRY_OPT_CONSTANTS] = 
 	GTK_ENTRY(lookup_widget(window.options, "entry_constants_file"));
     entry_options[ENTRY_OPT_CONSTANTS] = opt_strp("string_opt_constants_file");
@@ -436,7 +473,12 @@ option_gui_write_entry_widgets(gchar ***entry_options, GtkEntry **entry_widgets)
 void
 option_gui_set_up_window(void)
 {
+#ifdef DEBUG
+    printf("option_gui_set_up_window\n");
+#endif
+
     gint i;
+    gchar buf[SMALL];
     GtkToggleButton *bool_widgets[BOOL_OPT_END];
     gint *bool_options[BOOL_OPT_END];
 
@@ -446,20 +488,32 @@ option_gui_set_up_window(void)
     GtkEntry *entry_widgets[ENTRY_OPT_END];
     gchar **entry_options[ENTRY_OPT_END];
 
+    GtkToggleButton *news_popup_buttons[3] = 
+        {GTK_TOGGLE_BUTTON(lookup_widget(window.options, "radiobutton_news_popup_no")),
+         GTK_TOGGLE_BUTTON(lookup_widget(window.options, "radiobutton_news_popup_user")),
+         GTK_TOGGLE_BUTTON(lookup_widget(window.options, "radiobutton_news_popup_always"))};
+
     treeview_show_language_combo();
+    treeview_show_training_hotels_combo();
 
     option_gui_write_bool_widgets(bool_options, bool_widgets);
     option_gui_write_spin_widgets(spin_options, spin_widgets);
     option_gui_write_entry_widgets(entry_options, entry_widgets);
 
     for(i=0;i<BOOL_OPT_END;i++)
-	gtk_toggle_button_set_active(bool_widgets[i], *(bool_options[i]));
-
+        gtk_toggle_button_set_active(bool_widgets[i], *(bool_options[i]));
+	
     for(i=0;i<SPIN_OPT_END;i++)
 	gtk_spin_button_set_value(spin_widgets[i], (gfloat)(*(spin_options[i])));
 
     for(i=0;i<ENTRY_OPT_END;i++)
 	gtk_entry_set_text(entry_widgets[i], *(entry_options[i]));
+
+    sprintf(buf, "%d", CAMP_SCALE_MAX - gtk_spin_button_get_value_as_int(
+		GTK_SPIN_BUTTON(lookup_widget(window.options, "spinbutton_recreation"))));
+    gtk_label_set_text(GTK_LABEL(lookup_widget(window.options, "label_training")), buf);
+
+    gtk_toggle_button_set_active(news_popup_buttons[opt_int("int_opt_news_popup")], TRUE);
 }
 
 /** Read the widget states in the options window and set the
@@ -467,17 +521,28 @@ option_gui_set_up_window(void)
 void
 option_gui_write_options(void)
 {
+#ifdef DEBUG
+    printf("option_gui_write_options\n");
+#endif
+
     gint i;
     gint language_index = 
 	gtk_combo_box_get_active(GTK_COMBO_BOX(lookup_widget(window.options, "combobox_languages")));
+    gint training_camp_hotel =
+	gtk_combo_box_get_active(GTK_COMBO_BOX(lookup_widget(window.options, "combobox_hotel"))) + 1;
     GtkToggleButton *bool_widgets[BOOL_OPT_END];
     gint *bool_options[BOOL_OPT_END];
     GtkSpinButton *spin_widgets[SPIN_OPT_END];
     gint *spin_options[SPIN_OPT_END];
     GtkEntry *entry_widgets[ENTRY_OPT_END];
     gchar **entry_options[ENTRY_OPT_END];
-    
+    GtkToggleButton *news_popup_buttons[3] = 
+        {GTK_TOGGLE_BUTTON(lookup_widget(window.options, "radiobutton_news_popup_no")),
+         GTK_TOGGLE_BUTTON(lookup_widget(window.options, "radiobutton_news_popup_user")),
+         GTK_TOGGLE_BUTTON(lookup_widget(window.options, "radiobutton_news_popup_always"))};
+
     language_set(language_index);
+    opt_user_set_int("int_opt_user_training_camp_hotel", training_camp_hotel);
 
     option_gui_write_bool_widgets(bool_options, bool_widgets);
     option_gui_write_spin_widgets(spin_options, spin_widgets);
@@ -501,5 +566,12 @@ option_gui_write_options(void)
 	    on_button_back_to_main_clicked(NULL, NULL);
     }
 
+    for(i = 0; i < 3; i++)
+        if(gtk_toggle_button_get_active(news_popup_buttons[i]))
+        {
+            opt_set_int("int_opt_news_popup", i);
+            break;
+        }
+                
     game_gui_write_check_items();
 }
