@@ -45,6 +45,10 @@
 Player
 player_new(Team *tm, gfloat average_talent, gboolean new_id)
 {
+#ifdef DEBUG
+    printf("player_new\n");
+#endif
+
     gint i;
     gfloat skill_factor = 
 	math_rnd(1 - const_float("float_player_average_talent_variance"),
@@ -73,7 +77,7 @@ player_new(Team *tm, gfloat average_talent, gboolean new_id)
 
     new.talent = 
 	CLAMP(average_talent * skill_factor, 0,
-	      const_float("float_player_max_skill"));//85;
+	      const_float("float_player_max_skill"));;
 
     new.skill = player_skill_from_talent(&new);
     new.cskill = new.skill;
@@ -109,6 +113,10 @@ player_new(Team *tm, gfloat average_talent, gboolean new_id)
 void
 player_complete_def(Player *pl, gfloat average_talent)
 {
+#ifdef DEBUG
+    printf("player_complete_def\n");
+#endif
+
     gint i;
     gfloat skill_factor = 
 	math_rnd(1 - const_float("float_player_average_talent_variance"),
@@ -175,6 +183,10 @@ player_complete_def(Player *pl, gfloat average_talent)
 gint
 player_get_position_from_structure(gint structure, gint player_number)
 {
+#ifdef DEBUG
+    printf("player_get_position_from_structure\n");
+#endif
+
     gint position = -1;
     gint bound[2] =
 	{math_get_place(structure, 3) + 1,
@@ -205,6 +217,10 @@ player_get_position_from_structure(gint structure, gint player_number)
 gfloat
 player_skill_from_talent(const Player *pl)
 {
+#ifdef DEBUG
+    printf("player_skill_from_talent\n");
+#endif
+
     gfloat skill = pl->talent, cur_age = pl->peak_age;
 
     if(pl->age < pl->peak_age)
@@ -241,6 +257,10 @@ player_skill_from_talent(const Player *pl)
 void
 player_estimate_talent(Player *pl)
 {
+#ifdef DEBUG
+    printf("player_estimate_talent\n");
+#endif
+
     gint i, j;
     gfloat scout_deviance[QUALITY_END];
 
@@ -269,6 +289,10 @@ player_estimate_talent(Player *pl)
 gint
 player_assign_value(const Player *pl)
 {
+#ifdef DEBUG
+    printf("player_assign_value\n");
+#endif
+
     gfloat value;
 
     value = powf((const_float("float_player_value_skill_weight") * pl->skill +
@@ -292,6 +316,10 @@ player_assign_value(const Player *pl)
 gint
 player_assign_wage(const Player *pl)
 {
+#ifdef DEBUG
+    printf("player_assign_wage\n");
+#endif
+
     gfloat wage;
 
     wage = rint(((gfloat)pl->value * const_float("float_player_wage_value_factor")) *
@@ -345,6 +373,10 @@ player_of_idx_team(const Team *tm, gint number)
 Player*
 player_of_id_team(const Team *tm, gint id)
 {
+#ifdef DEBUG
+    printf("player_of_id_team\n");
+#endif
+
     gint i;
     
     for(i=0;i<tm->players->len;i++)
@@ -362,6 +394,10 @@ player_of_id_team(const Team *tm, gint id)
 gboolean
 query_player_id_in_team(gint player_id, const Team *tm)
 {
+#ifdef DEBUG
+    printf("query_player_id_in_team\n");
+#endif
+
     gint i;
 
     for(i=0;i<tm->players->len;i++)
@@ -380,6 +416,10 @@ query_player_id_in_team(gint player_id, const Team *tm)
 gint
 player_all_games_goals(const Player *pl, gint type)
 {
+#ifdef DEBUG
+    printf("player_all_games_goals\n");
+#endif
+
     gint i, sum = 0;
 
     for(i=0;i<pl->games_goals->len;i++)
@@ -400,6 +440,10 @@ player_all_games_goals(const Player *pl, gint type)
 gint
 player_all_cards(const Player *pl)
 {
+#ifdef DEBUG
+    printf("player_all_cards\n");
+#endif
+
     gint i, sum = 0;
 
     for(i=0;i<pl->cards->len;i++)
@@ -416,6 +460,10 @@ player_all_cards(const Player *pl)
 gint
 player_compare_func(gconstpointer a, gconstpointer b, gpointer data)
 {
+#ifdef DEBUG
+    printf("player_compare_func\n");
+#endif
+
     gint data_int = ABS(GPOINTER_TO_INT(data));
     gint data_int2 = GPOINTER_TO_INT(data);
     gint type = data_int % 100;
@@ -481,6 +529,10 @@ player_compare_func(gconstpointer a, gconstpointer b, gpointer data)
 gint
 player_compare_substitute_func(gconstpointer a, gconstpointer b, gpointer data)
 {
+#ifdef DEBUG
+    printf("player_compare_substitute_func\n");
+#endif
+
     const Player *pl1 = *(const Player**)a;
     const Player *pl2 = *(const Player**)b;
     gint position = GPOINTER_TO_INT(data);
@@ -535,6 +587,10 @@ player_compare_substitute_func(gconstpointer a, gconstpointer b, gpointer data)
 gboolean
 player_substitution_good_structure(gint old_structure, gint old_pos, gint player_pos)
 {
+#ifdef DEBUG
+    printf("player_substitution_good_structure\n");
+#endif
+
     gint accepted_structures[5] = {532, 442, 352, 433, 343};
     gint new_structure = 
 	old_structure - (gint)rint(powf(10, PLAYER_POS_FORWARD - old_pos)) +
@@ -550,6 +606,10 @@ player_substitution_good_structure(gint old_structure, gint old_pos, gint player
 void
 player_copy(Player *pl, Team *tm, gint insert_at)
 {
+#ifdef DEBUG
+    printf("player_copy\n");
+#endif
+
     Player new = *pl;
 
     new.team = tm;
@@ -575,6 +635,10 @@ player_copy(Player *pl, Team *tm, gint insert_at)
 void
 player_move(Team *tm1, gint player_number, Team *tm2, gint insert_at)
 {
+#ifdef DEBUG
+    printf("player_move\n");
+#endif
+
     Player pl = *player_of_idx_team(tm1, player_number);
 
     pl.team = tm2;
@@ -588,6 +652,10 @@ player_move(Team *tm1, gint player_number, Team *tm2, gint insert_at)
 void
 player_swap(Team *tm1, gint player_number1, Team *tm2, gint player_number2)
 {
+#ifdef DEBUG
+    printf("player_swap\n");
+#endif
+
     gint move = (tm1 == tm2 && player_number1 < player_number2) ? 
 	-1 : 1;
 
@@ -636,6 +704,10 @@ player_swap(Team *tm1, gint player_number1, Team *tm2, gint player_number2)
 gfloat
 player_get_cskill(const Player *pl, gint position, gboolean check_health)
 {
+#ifdef DEBUG
+    printf("player_get_cskill\n");
+#endif
+
     gfloat cskill_factor;
 
     if(check_health &&
@@ -668,6 +740,10 @@ player_get_cskill(const Player *pl, gint position, gboolean check_health)
 gint
 player_is_banned(const Player *pl)
 {
+#ifdef DEBUG
+    printf("player_is_banned\n");
+#endif
+
     Fixture *fix = team_get_fixture(pl->team, FALSE);
     gint yellow_red = -1, yellow, red;
 
@@ -716,6 +792,10 @@ player_get_game_skill(const Player *pl, gboolean skill, gboolean count_special)
 void
 player_decrease_fitness(Player *pl)
 {
+#ifdef DEBUG
+    printf("player_decrease_fitness\n");
+#endif
+
     gfloat goalie_factor = 
 	1 - const_float("float_player_fitness_decrease_factor_goalie") *
 	(pl->cpos == 0);
@@ -745,7 +825,8 @@ player_decrease_fitness(Player *pl)
 			goalie_factor * boost_factor * streak_factor);
     }
 
-    pl->fitness = MAX(0, pl->fitness);
+    if(pl->fitness < 0)
+        pl->fitness = 0;
 }
 
 
@@ -757,6 +838,10 @@ player_decrease_fitness(Player *pl)
 void
 player_update_fitness(Player *pl)
 {
+#ifdef DEBUG
+    printf("player_update_fitness\n");
+#endif
+
     gfloat variance = 
 	math_rnd(1 - const_float("float_player_fitness_increase_variance"),
 		 1 + const_float("float_player_fitness_increase_variance"));
@@ -794,6 +879,10 @@ player_update_fitness(Player *pl)
 gint
 player_card_get(const Player *pl, gint clid, gint card_type)
 {
+#ifdef DEBUG
+    printf("player_card_get\n");
+#endif
+
     gint i;
     gint return_value = 0;
     
@@ -821,6 +910,10 @@ player_card_get(const Player *pl, gint clid, gint card_type)
 void
 player_card_set(Player *pl, gint clid, gint card_type, gint value, gboolean diff)
 {
+#ifdef DEBUG
+    printf("player_card_set\n");
+#endif
+
     gint i, *card_value = NULL;
     PlayerCard new;
 
@@ -861,6 +954,10 @@ player_card_set(Player *pl, gint clid, gint card_type, gint value, gboolean diff
 gint
 player_games_goals_get(const Player *pl, gint clid, gint type)
 {
+#ifdef DEBUG
+    printf("player_games_goals_get\n");
+#endif
+
     gint i, return_value = 0;
 
     for(i=0;i<pl->games_goals->len;i++)
@@ -890,6 +987,10 @@ player_games_goals_get(const Player *pl, gint clid, gint type)
 void
 player_games_goals_set(Player *pl, gint clid, gint type, gint value)
 {
+#ifdef DEBUG
+    printf("player_games_goals_set\n");
+#endif
+
     gint i, *games_goals_value = NULL;
     PlayerGamesGoals new;
 
@@ -927,6 +1028,10 @@ player_games_goals_set(Player *pl, gint clid, gint type, gint value)
 void
 player_update_skill(Player *pl)
 {
+#ifdef DEBUG
+    printf("player_update_skill\n");
+#endif
+
     gint i;
 
     if(!query_player_is_youth(pl))
@@ -982,6 +1087,10 @@ player_update_skill(Player *pl)
 void
 player_update_injury(Player *pl)
 {
+#ifdef DEBUG
+    printf("player_update_injury\n");
+#endif
+
     gint i, j;
     gfloat rndom;
     gint physio = (query_player_is_cpu(pl)) ? 
@@ -1025,6 +1134,10 @@ player_update_injury(Player *pl)
 void
 player_update_streak(Player *pl)
 {
+#ifdef DEBUG
+    printf("player_update_streak\n");
+#endif
+
     gfloat streak_type, streak_prob, 
 	streak_length, decrease_factor = 0;
     gfloat streak_prob_factor = 
@@ -1099,6 +1212,14 @@ player_update_streak(Player *pl)
 void
 player_update_weekly(Player *pl)
 {
+#ifdef DEBUG
+    printf("player_update_weekly\n");
+#endif
+
+    // workaround, possibly unnecessary
+    if(pl->fitness < 0)
+	pl->fitness = const_float("float_player_fitness_lower");
+    
     if(pl->health > 0)
 	player_update_injury(pl);
     else
@@ -1136,8 +1257,13 @@ player_update_weekly(Player *pl)
 void
 player_remove_contract(Player *pl)
 {
-    user_event_add(user_from_team(pl->team), EVENT_TYPE_PLAYER_LEFT, -1, -1, NULL,
-		   pl->name);
+#ifdef DEBUG
+    printf("player_remove_contract\n");
+#endif
+
+    if(debug < 50)
+        user_event_add(user_from_team(pl->team), EVENT_TYPE_PLAYER_LEFT, -1, -1, NULL,
+                       pl->name);
     player_remove_from_team(pl->team, player_id_index(pl->team, pl->id));
 }
 
@@ -1146,6 +1272,10 @@ player_remove_contract(Player *pl)
 void
 player_remove_from_team(Team *tm, gint idx)
 {
+#ifdef DEBUG
+    printf("player_remove_from_team\n");
+#endif
+
     gint usr_idx = team_is_user(tm);
 
     if(usr_idx != -1 && 
@@ -1165,6 +1295,10 @@ player_remove_from_team(Team *tm, gint idx)
 void
 player_update_post_match(Player *pl, const Fixture *fix)
 {
+#ifdef DEBUG
+    printf("player_update_post_match\n");
+#endif
+
     gint yellow_red = league_cup_get_yellow_red(fix->clid);
     gint winner = -1;
 
@@ -1205,9 +1339,13 @@ player_update_post_match(Player *pl, const Fixture *fix)
 void
 player_replace_by_new(Player *pl, gboolean free_player)
 {
+#ifdef DEBUG
+    printf("player_replace_by_new\n");
+#endif
+
     Team *tm = pl->team;
     gint idx = player_id_index(tm, pl->id);
-    Player new = player_new(tm, team_get_average_skill(tm, FALSE), FALSE);
+    Player new = player_new(tm, team_get_average_talent(tm), FALSE);
         
     new.name = name_get(pl->team->names_file);
     new.pos = pl->pos;
@@ -1227,6 +1365,10 @@ player_replace_by_new(Player *pl, gboolean free_player)
 void
 player_update_week_roundly(Team *tm, gint idx)
 {
+#ifdef DEBUG
+    printf("player_update_week_roundly\n");
+#endif
+
     Player *pl = player_of_idx_team(tm, idx);
 
     if(pl->health == 0 && 
@@ -1241,7 +1383,16 @@ player_update_week_roundly(Team *tm, gint idx)
 /** Return injury descriptions.  */
 gchar*
 player_injury_to_char(gint injury_type)
-{      
+{
+#ifdef DEBUG
+    printf("player_injury_to_char\n");
+#endif
+
+#ifdef DEBUG
+    printf("player_injury_to_char\n");
+#endif
+
+       
     switch(injury_type)
     {
 	default:
@@ -1295,6 +1446,10 @@ player_injury_to_char(gint injury_type)
 void
 player_season_start(Player *pl, gfloat skill_change)
 {
+#ifdef DEBUG
+    printf("player_season_start\n");
+#endif
+
     gint i;
 
     if(pl->games_goals->len > 0)
@@ -1333,6 +1488,14 @@ player_season_start(Player *pl, gfloat skill_change)
 gchar*
 player_get_last_name(const gchar *name)
 {
+#ifdef DEBUG
+    printf("player_get_last_name\n");
+#endif
+
+#ifdef DEBUG
+    printf("player_get_last_name\n");
+#endif
+
     gint i;
     gchar buf[SMALL];
     gchar *rev_name = NULL;
@@ -1367,6 +1530,10 @@ player_get_last_name(const gchar *name)
 GPtrArray*
 player_get_pointers_from_array(const GArray *players_array)
 {
+#ifdef DEBUG
+    printf("player_get_pointers_from_array\n");
+#endif
+
     gint i;
     GPtrArray *players = g_ptr_array_new();
 
@@ -1381,6 +1548,10 @@ player_get_pointers_from_array(const GArray *players_array)
 void
 player_move_to_ya(gint idx)
 {
+#ifdef DEBUG
+    printf("player_move_to_ya\n");
+#endif
+
     Player *pl = player_of_idx_team(current_user.tm, idx);
     Player player = *pl;
 
@@ -1398,9 +1569,15 @@ player_move_to_ya(gint idx)
 void
 player_move_from_ya(gint idx)
 {
+#ifdef DEBUG
+    printf("player_move_from_ya\n");
+#endif
+
     Player *pl = &g_array_index(current_user.youth_academy.players, Player, idx);
     Player player = *pl;
 
+    player.contract = const_float("float_player_contract_youth");
+
     g_array_remove_index(current_user.youth_academy.players, idx);
     g_array_append_val(current_user.tm->players, player);
 }
@@ -1410,6 +1587,10 @@ player_move_from_ya(gint idx)
 void
 player_streak_add_to_prob(Player *pl, gfloat add)
 {
+#ifdef DEBUG
+    printf("player_streak_add_to_prob\n");
+#endif
+
     pl->streak_prob += add;
     pl->streak_prob = CLAMP(pl->streak_prob, -1, 1);
 }
@@ -1418,6 +1599,10 @@ player_streak_add_to_prob(Player *pl, gfloat add)
 gboolean
 query_player_is_in_ya(const Player *pl)
 {
+#ifdef DEBUG
+    printf("query_player_is_in_ya\n");
+#endif
+
     gint i;
 
     for(i=0;i<pl->team->players->len;i++)
@@ -1426,3 +1611,60 @@ query_player_is_in_ya(const Player *pl)
 
     return TRUE;
 }
+
+/** Find out if a star balks when offered a new or a renewed contract
+    because there are already enough stars on the prospective new team. */
+gboolean
+query_player_star_balks(const Player *pl, const Team *tm, gboolean transfer)
+{
+#ifdef DEBUG
+    printf("query_player_star_balks\n");
+#endif
+
+    gint i;
+    gint number_of_stars_field;
+    gint number_of_stars_goal;
+    gfloat skill_limit;
+
+    /* Weak players never balk. */
+    if(pl->skill < const_float("float_transfer_star_skill_limit"))
+	return FALSE;
+
+    /* There is some chance that the new star doesn't balk at all. */
+    if((transfer && math_rnd(0, 1) < const_float("float_transfer_star_no_balk")) ||
+       (!transfer && math_rnd(0, 1) < const_float("float_contract_star_no_balk")))
+	return FALSE;
+
+    /* Find out if there are any stars at all on the team. */
+    number_of_stars_field = 
+	number_of_stars_goal = 0;
+    skill_limit = (transfer ? 
+		   const_float("float_transfer_star_skill_limit") :
+		   const_float("float_contract_star_skill_limit"));
+    for(i = 0; i < tm->players->len; i++)
+    {
+	if(g_array_index(tm->players, Player, i).skill > skill_limit)
+	{
+	    if(g_array_index(tm->players, Player, i).pos == PLAYER_POS_GOALIE)
+		number_of_stars_goal++;
+	    else
+		number_of_stars_field++;
+	}
+    }
+    
+    if(pl->pos == PLAYER_POS_GOALIE)
+    {
+	if(number_of_stars_goal == 0)
+	    return FALSE;
+	else
+	    return (math_rnd(0, 1) > const_float("float_transfer_star_goalie_accepts"));
+    }
+    else
+    {
+	if(number_of_stars_field == 0)
+	    return FALSE;
+	else
+	    return (math_rnd(0, 1) > 1 - number_of_stars_field * 
+		    const_float("float_transfer_star_prob_decrease"));
+    }
+}
