@@ -39,6 +39,7 @@
 #include "maths.h"
 #include "misc.h"
 #include "name.h"
+#include "news.h"
 #include "option.h"
 #include "player.h"
 #include "start_end.h"
@@ -59,7 +60,7 @@ typedef void(*WeekFunc)(void);
     is ended. */
 WeekFunc end_week_round_funcs[] =
 {end_week_round_results, end_week_round_sort_tables,
- end_week_round_update_fixtures, NULL};
+ end_week_round_generate_news, end_week_round_update_fixtures, NULL};
 
 /** Array of functions called when a week round
     is started. */
@@ -69,9 +70,10 @@ WeekFunc start_week_round_funcs[] =
 /** Array of functions called when a week
     is started. */
 WeekFunc start_week_funcs[] = 
-{start_week_add_cups, start_week_update_users,
+{start_week_update_leagues, start_week_add_cups, start_week_update_users,
  start_week_update_teams, start_week_update_user_finances,
- youth_academy_update_weekly, transfer_update, job_update, NULL};
+ youth_academy_update_weekly, transfer_update, job_update,
+ finance_update_current_interest, NULL};
 
 WeekFunc end_week_funcs[] = {stat_update_leagues, end_week_hide_cups, NULL};
 
@@ -79,6 +81,10 @@ WeekFunc end_week_funcs[] = {stat_update_leagues, end_week_hide_cups, NULL};
 void
 start_new_game(void)
 {
+#ifdef DEBUG
+    printf("start_new_game\n");
+#endif
+
     start_write_variables();
 
     start_generate_league_teams();
@@ -89,6 +95,10 @@ start_new_game(void)
 void
 start_new_season(void)
 {
+#ifdef DEBUG
+    printf("start_new_season\n");
+#endif
+
     gint i, j;
     gchar buf[SMALL];
 
@@ -96,6 +106,20 @@ start_new_season(void)
     free_names(TRUE);
     stat5 = STATUS_GENERATE_TEAMS;
 
+    if(season == 1)
+    {
+        for(i=0;i<ligs->len;i++)
+        {
+            league_add_table(&lig(i));
+            league_check_new_tables(&lig(i));
+        }
+
+	for(i=0;i<cps->len;i++)
+	    if(cp(i).add_week <= 0)
+		g_ptr_array_add(acps, &cp(i));
+    }
+
+    /* Remove cups that don't start at the beginning of season. */
     for(i = acps->len - 1; i >= 0; i--)
     {
 	g_ptr_array_free(acp(i)->team_names, TRUE);
@@ -105,12 +129,10 @@ start_new_season(void)
 	    g_ptr_array_remove_index(acps, i);
     }
 
+    /* Deal with cups that have to take place before promotion/relegation. */
     for(i=cps->len - 1; i >= 0; i--)
 	if(cp(i).add_week == -1)
-	{
-	    cup_reset(&cp(i));
 	    fixture_write_cup_fixtures(&cp(i));
-	}
 
     if(season > 1)
     {
@@ -121,8 +143,12 @@ start_new_season(void)
 			     usr(i).tm->name, 
 			     league_cup_get_name_string(usr(i).tm->clid), 
 			     buf, NULL);
+
+	    usr(i).counters[COUNT_USER_TRAININGS_LEFT_SEASON] =
+		const_int("int_training_camps_per_season");
 	}
 
+        /* Promotion/relegation, mainly. */
 	start_new_season_league_changes();
 
 	for(i=0;i<users->len;i++)
@@ -142,38 +168,42 @@ start_new_season(void)
 
 	start_new_season_reset_ids();
     }
-    else
-    {
-	for(i=0;i<cps->len;i++)
-	    if(cp(i).add_week <= 0)
-		g_ptr_array_add(acps, &cp(i));
-    }
-		
+    
+    /* We have to reset all fixture arrays beforehand because
+       of interleague scheduling (see joined_league). */
     for(i=0;i<ligs->len;i++)
-	if(lig(i).active)
+	if(query_league_active(&lig(i)))
+        {
+            g_array_free(lig(i).fixtures, TRUE);
+            lig(i).fixtures = g_array_new(FALSE, FALSE, sizeof(Fixture));            
+        }
+
+    for(i=0;i<ligs->len;i++)
+	if(query_league_active(&lig(i)))
 	    fixture_write_league_fixtures(&lig(i));
 
+    /* Loop backwards because the national cup is usually
+       the first the results are often still 
+       needed for the international cups. */
     for(i=cps->len - 1; i >= 0; i--)
     {
-	if(cp(i).add_week >= 0)
-	{
-	    cup_reset(&cp(i));
-	    
-	    if(cp(i).add_week == 0)
-		fixture_write_cup_fixtures(&cp(i));
-	}
+        if(cp(i).add_week == 0)
+            fixture_write_cup_fixtures(&cp(i));
+        /* Reset team pointers using the stored ids
+           (pointers might have changed because of prom/rel). */
 	else if(cp(i).add_week == -1)
-	{
-	    for(j=0;j<cp(i).fixtures->len;j++)
-	    {
-		g_array_index(cp(i).fixtures, Fixture, j).teams[0] =
-		    team_of_id(g_array_index(cp(i).fixtures, Fixture, j).team_ids[0]);
-		g_array_index(cp(i).fixtures, Fixture, j).teams[1] =
-		    team_of_id(g_array_index(cp(i).fixtures, Fixture, j).team_ids[1]);
-	    }
-	}
+            fixture_refresh_team_pointers(cp(i).fixtures);
+        else if(!query_cup_self_referential(&cp(i)))
+            cup_reset(&cp(i));
     }
-    
+
+    for(i = acps->len - 1; i >= 0; i--)
+        if(!cup_check_fixtures(acp(i)))
+        {
+            cup_reset(acp(i));
+            g_ptr_array_remove_index(acps, i);
+        }
+
     stat5 = -1;
 
     for(i=0;i<name_lists->len;i++)
@@ -188,6 +218,10 @@ start_new_season(void)
 void
 start_write_variables(void)
 {
+#ifdef DEBUG
+    printf("start_write_variables\n");
+#endif
+
     gint i;
 
     season = 1;
@@ -201,6 +235,10 @@ start_write_variables(void)
 void
 start_generate_league_teams(void)
 {
+#ifdef DEBUG
+    printf("start_generate_league_teams\n");
+#endif
+
     gint i, j;    
 
     stat5 = STATUS_GENERATE_TEAMS;
@@ -222,6 +260,10 @@ start_generate_league_teams(void)
 void
 start_new_season_reset_ids(void)
 {
+#ifdef DEBUG
+    printf("start_new_season_reset_ids\n");
+#endif
+
     gint i, max;
 
     max = -1;
@@ -243,6 +285,10 @@ start_new_season_reset_ids(void)
 void
 end_week_round(void)
 {
+#ifdef DEBUG
+    printf("end_week_round\n");
+#endif
+
     gint i = 0;
     gboolean new_week = TRUE;
     WeekFunc *end_func = end_week_round_funcs;
@@ -299,10 +345,22 @@ end_week_round(void)
 void
 end_week_round_results(void)
 {
+#ifdef DEBUG
+    printf("end_week_round_results\n");
+#endif
+
     gint i, j, done = 0;
+    LiveGame live_game;
     gchar buf[SMALL], buf2[SMALL];
     gfloat num_matches =
 	(gfloat)fixture_get_number_of_matches(week, week_round);
+    gint usr_idx;
+
+    /** Free the matches from last week. */
+    for(i = 0; i < live_games->len; i++)
+        free_live_game(&g_array_index(live_games, LiveGame, i));
+    g_array_free(live_games, TRUE);
+    live_games = g_array_new(FALSE, FALSE, sizeof(LiveGame));
     
     for(i=0;i<ligs->len;i++)
     {
@@ -310,8 +368,18 @@ end_week_round_results(void)
 	    if(g_array_index(lig(i).fixtures, Fixture, j).week_number == week &&
 	       g_array_index(lig(i).fixtures, Fixture, j).week_round_number == week_round &&
 	       g_array_index(lig(i).fixtures, Fixture, j).attendance == -1)
-	    {
-		live_game_calculate_fixture(&g_array_index(lig(i).fixtures, Fixture, j));
+	    {                
+                usr_idx = fixture_user_team_involved(&g_array_index(lig(i).fixtures, Fixture, j));
+
+                if(usr_idx == -1)
+                {
+                    g_array_append_val(live_games, live_game);
+                    live_game_calculate_fixture(&g_array_index(lig(i).fixtures, Fixture, j),
+                                                &g_array_index(live_games, LiveGame, live_games->len - 1));
+                }
+                else
+                    live_game_calculate_fixture(&g_array_index(lig(i).fixtures, Fixture, j),
+                                                &usr(usr_idx).live_game);
 
 		done++;
 		fixture_result_to_buf(&g_array_index(lig(i).fixtures, Fixture, j),
@@ -329,13 +397,25 @@ end_week_round_results(void)
     }
 
     for(i=0;i<acps->len;i++)
+    {
 	for(j=0;j<acp(i)->fixtures->len;j++)
 	{
 	    if(g_array_index(acp(i)->fixtures, Fixture, j).week_number == week &&
 	       g_array_index(acp(i)->fixtures, Fixture, j).week_round_number == week_round &&
 	       g_array_index(acp(i)->fixtures, Fixture, j).attendance == -1)
 	    {
-		live_game_calculate_fixture(&g_array_index(acp(i)->fixtures, Fixture, j));
+
+                usr_idx = fixture_user_team_involved(&g_array_index(acp(i)->fixtures, Fixture, j));
+
+                if(usr_idx == -1)
+                {
+                    g_array_append_val(live_games, live_game);
+                    live_game_calculate_fixture(&g_array_index(acp(i)->fixtures, Fixture, j),
+                                                &g_array_index(live_games, LiveGame, live_games->len - 1));
+                }
+                else
+                    live_game_calculate_fixture(&g_array_index(acp(i)->fixtures, Fixture, j),
+                                                &usr(usr_idx).live_game);
 
 		done++;
 		fixture_result_to_buf(&g_array_index(acp(i)->fixtures, Fixture, j), 
@@ -350,7 +430,8 @@ end_week_round_results(void)
 		    g_print("%s \n", buf2);
 	    }
 	}
-
+    }
+    
     gui_show_progress(-1, "", PIC_TYPE_MATCHPIC);
 }
 
@@ -358,17 +439,24 @@ end_week_round_results(void)
 void
 end_week_round_sort_tables(void)
 {
+#ifdef DEBUG
+    printf("end_week_round_sort_tables\n");
+#endif
+
     gint i, j, k;
 
     for(i=0;i<ligs->len;i++)
 	if(query_fixture_in_week_round(lig(i).id, week, week_round))
 	{
-	    for(j=0;j<lig(i).table.elements->len;j++)
-		g_array_index(lig(i).table.elements, TableElement, j).old_rank = j;
-
-	    g_array_sort_with_data(lig(i).table.elements,
-				   (GCompareDataFunc)table_element_compare_func,
-				   GINT_TO_POINTER(lig(i).id));
+            for(k = 0; k < lig(i).tables->len; k++)
+            {
+                for(j=0;j<g_array_index(lig(i).tables, Table, k).elements->len;j++)
+                    g_array_index(g_array_index(lig(i).tables, Table, k).elements, TableElement, j).old_rank = j;
+                
+                g_array_sort_with_data(g_array_index(lig(i).tables, Table, k).elements,
+                                       (GCompareDataFunc)table_element_compare_func,
+                                       GINT_TO_POINTER(lig(i).id));
+            }
 	}
 
     for(i=0;i<acps->len;i++)
@@ -393,43 +481,79 @@ end_week_round_sort_tables(void)
 void
 end_week_round_update_fixtures(void)
 {
+#ifdef DEBUG
+    printf("end_week_round_update_fixtures\n");
+#endif
+
     gint i;
 
     for(i=0;i<acps->len;i++)
-	if(acp(i)->next_fixture_update_week == week &&
-	   acp(i)->next_fixture_update_week_round == week_round)
+	if(acp(i)->next_fixture_update_week <= week &&
+	   acp(i)->next_fixture_update_week_round <= week_round)
 	    fixture_update(acp(i));
 
     for(i=0;i<ligs->len;i++)
-	if(lig(i).active && week == 
+	if(query_league_active(&lig(i)) && week == 
 	   g_array_index(
 	       lig(i).fixtures, Fixture, lig(i).fixtures->len - 1).week_number && 
 	   week_round == 1 &&
-	   team_is_user(g_array_index(lig(i).table.elements, TableElement, 0).team) != -1)
-	    user_history_add(&usr(team_is_user(g_array_index(lig(i).table.elements, TableElement, 0).team)),
-			     USER_HISTORY_CHAMPION, 
-			     g_array_index(lig(i).table.elements, 
-					   TableElement, 0).team->name,
-			     league_cup_get_name_string(lig(i).id),
-			     NULL, NULL);
+	   team_is_user(g_array_index(league_table((&lig(i)))->elements, TableElement, 0).team) != -1)
+           user_history_add(&usr(team_is_user(g_array_index(league_table((&lig(i)))->elements, TableElement, 0).team)),
+                            USER_HISTORY_CHAMPION, 
+                            g_array_index(league_table((&lig(i)))->elements, 
+                                          TableElement, 0).team->name,
+                            league_cup_get_name_string(lig(i).id),
+                            NULL, NULL);
     
     for(i=0;i<cps->len;i++)
     {
 	if(cp(i).add_week == 1000 && 
-	   cp(i).fixtures->len == 0 &&
+	   query_cup_hidden(&cp(i)) &&
 	   query_cup_begins(&cp(i)))
 	{
 	    cp(i).last_week = cup_get_last_week_from_first(&cp(i), week + 1);
-	    fixture_write_cup_fixtures(&cp(i));
-	    g_ptr_array_add(acps, &cp(i));
+            
+	    if(fixture_write_cup_fixtures(&cp(i)))
+                g_ptr_array_add(acps, &cp(i));
 	}
     }
 }
 
+/** Write newspaper articles after week round. */
+void
+end_week_round_generate_news(void)
+{
+    gint i;
+
+    /** News for user matches. */
+    for(i = 0; i < users->len; i++)
+        if(usr(i).live_game.fix != NULL &&
+           usr(i).live_game.fix->week_number == week &&
+           usr(i).live_game.fix->week_round_number == week_round &&
+           news_check_match_relevant(&usr(i).live_game))
+            news_generate_match(&usr(i).live_game);
+
+    /** News for other matches. */
+    for(i = 0; i < live_games->len; i++)
+        if(news_check_match_relevant(&g_array_index(live_games, LiveGame, i)))
+            news_generate_match(&g_array_index(live_games, LiveGame, i));
+
+    /* Get rid of older news. */
+    while(newspaper.articles->len > const_int("int_news_history_length"))
+    {
+        free_newspaper_article(&g_array_index(newspaper.articles, NewsPaperArticle, 0));
+        g_array_remove_index(newspaper.articles, 0);
+    }
+}
+
 /** Start a new week round. */
 void
 start_week_round(void)
 {
+#ifdef DEBUG
+    printf("start_week_round\n");
+#endif
+
     WeekFunc *start_func = start_week_round_funcs;
 
     if(debug > 100)
@@ -444,11 +568,15 @@ start_week_round(void)
     if(!query_start_end_season_end() &&
 	opt_int("int_opt_skip") &&
        !query_user_games_this_week_round() &&
+       !query_user_events() &&
        ((week_round == 1 && 
 	 !query_user_games_in_week_round(week - 1, fixture_get_last_week_round(week - 1))) ||
 	(week_round > 1 && 
-	 !query_user_games_in_week_round(week, week_round - 1))))
+	 !query_user_games_in_week_round(week, week_round - 1)))) 
+    {
+	user_event_show_next();
 	end_week_round();
+    }
     else
     {
         cur_user = 0;
@@ -462,6 +590,10 @@ start_week_round(void)
 void
 start_week(void)
 {
+#ifdef DEBUG
+    printf("start_week\n");
+#endif
+
     WeekFunc *start_func = start_week_funcs;
 
     while(*start_func != NULL)
@@ -475,6 +607,10 @@ start_week(void)
 void
 end_week(void)
 {
+#ifdef DEBUG
+    printf("end_week\n");
+#endif
+
     WeekFunc *end_func = end_week_funcs;
 
     while(*end_func != NULL)
@@ -492,10 +628,14 @@ end_week(void)
 void
 end_week_hide_cups(void)
 {
+#ifdef DEBUG
+    printf("end_week_hide_cups\n");
+#endif
+
     gint i;
 
     for(i=acps->len - 1; i >= 0; i--)
-	if(query_cup_hide(acp(i)->id) &&
+	if(query_league_cup_has_property(acp(i)->id, "hide") &&
 	   g_array_index(acp(i)->fixtures, Fixture, acp(i)->fixtures->len - 1).attendance > 0)
 	    g_ptr_array_remove_index(acps, i);
 }
@@ -504,13 +644,17 @@ end_week_hide_cups(void)
 void
 start_week_add_cups(void)
 {
+#ifdef DEBUG
+    printf("start_week_add_cups\n");
+#endif
+
     gint i;
 
     for(i=0;i<cps->len;i++)
 	if(cp(i).add_week == week)
 	{
-	    fixture_write_cup_fixtures(&cp(i));
-	    g_ptr_array_add(acps, &cp(i));
+	    if(fixture_write_cup_fixtures(&cp(i)))
+                g_ptr_array_add(acps, &cp(i));            
 	}
 }
 
@@ -520,6 +664,10 @@ start_week_add_cups(void)
 void
 start_week_update_teams(void)
 {
+#ifdef DEBUG
+    printf("start_week_update_teams\n");
+#endif
+
     gint i, j;
     
     for(i=0;i<ligs->len;i++)
@@ -536,6 +684,10 @@ start_week_update_teams(void)
 void
 start_week_round_update_teams(void)
 {
+#ifdef DEBUG
+    printf("start_week_round_update_teams\n");
+#endif
+
     gint i, j;
     
     for(i=0;i<ligs->len;i++)
@@ -551,6 +703,10 @@ start_week_round_update_teams(void)
 void
 start_week_update_user_finances(void)
 {
+#ifdef DEBUG
+    printf("start_week_update_user_finances\n");
+#endif
+
     gint i;
 
     if(sett_int("int_opt_disable_finances"))
@@ -564,6 +720,10 @@ start_week_update_user_finances(void)
 void
 start_week_update_users(void)
 {
+#ifdef DEBUG
+    printf("start_week_update_users\n");
+#endif
+
     gint i;
 
     for(i=0;i<users->len;i++)
@@ -581,10 +741,28 @@ start_week_update_users(void)
     }
 }
 
+/** Create new tables if necessary etc. */
+void
+start_week_update_leagues(void)
+{
+#ifdef DEBUG
+    printf("start_week_update_leagues\n");
+#endif
+
+    gint i;
+
+    for(i = 0; i < ligs->len; i++)
+        league_check_new_tables(&lig(i));
+}
+
 /** Check whether the season has ended. */
 gboolean
 query_start_end_season_end(void)
 {
+#ifdef DEBUG
+    printf("query_start_end_season_end\n");
+#endif
+
     gint i, j;
 
     for(i=0;i<ligs->len;i++)
@@ -604,6 +782,10 @@ query_start_end_season_end(void)
 void
 start_new_season_league_changes(void)
 {
+#ifdef DEBUG
+    printf("start_new_season_league_changes\n");
+#endif
+
     gint i, j, k;
     gint league_size[ligs->len];
     GArray *team_movements = g_array_new(FALSE, FALSE, sizeof(TeamMove));
@@ -622,8 +804,7 @@ start_new_season_league_changes(void)
     league_team_movements_destinations(team_movements, league_size);
 
     for(i = team_movements->len - 1; i >= 0; i--)
-	if(g_array_index(team_movements, TeamMove, i).prom_rel_type == 
-	   PROM_REL_RELEGATION)
+	if(g_array_index(team_movements, TeamMove, i).prom_rel_type == PROM_REL_RELEGATION)
 	    g_array_prepend_val(
 		lig(g_array_index(
 			g_array_index(team_movements, TeamMove, i).dest_idcs, 
@@ -631,8 +812,7 @@ start_new_season_league_changes(void)
 		g_array_index(team_movements, TeamMove, i).tm);
     
     for(i=1;i<team_movements->len;i++)
-	if(g_array_index(team_movements, TeamMove, i).prom_rel_type != 
-	   PROM_REL_RELEGATION)
+	if(g_array_index(team_movements, TeamMove, i).prom_rel_type != PROM_REL_RELEGATION)
 	    g_array_append_val(
 		lig(g_array_index(
 			g_array_index(team_movements, TeamMove, i).dest_idcs, 
@@ -663,5 +843,9 @@ start_new_season_league_changes(void)
 void
 end_season(void)
 {
+#ifdef DEBUG
+    printf("end_season\n");
+#endif
+
     stat_create_season_stat();
 }
