@@ -124,10 +124,10 @@ GtkTreeModel*
 treeview_create_table(gint clid);
 
 void
-treeview_create_single_table(GtkListStore *liststore, const Table *table, gint number);
+treeview_create_single_table(GtkListStore *liststore, const Table *table, gint table_index);
 
 void
-treeview_table_write_header(GtkListStore *ls, const Table *table, gint number);
+treeview_table_write_header(GtkListStore *ls, const Table *table, gint table_index);
 
 void
 treeview_show_finances(GtkTreeView *treeview, const User* user);
@@ -136,7 +136,7 @@ void
 treeview_set_up_finances(GtkTreeView *treeview);
 
 GtkTreeModel*
-treeview_create_finances(const User* user);
+treeview_create_finances(const User *user);
 
 void
 treeview_show_player_list_team(GtkTreeView *treeview, const Team *tm, gint scout);
@@ -241,4 +241,10 @@ treeview_set_up_sponsors(GtkTreeView *treeview);
 void
 treeview_show_sponsors(const GArray *sponsors);
 
+GtkTreeModel*
+treeview_create_training_hotel_list(void);
+
+void
+treeview_show_training_hotels_combo(void);
+
 #endif
