@@ -51,6 +51,10 @@
 User
 user_new(void)
 {
+#ifdef DEBUG
+    printf("user_new\n");
+#endif
+
     User new;
 
     new.name = g_strdup("NONAME");
@@ -76,7 +80,6 @@ user_new(void)
 
     new.bets[0] = g_array_new(FALSE, FALSE, sizeof(BetUser));
     new.bets[1] = g_array_new(FALSE, FALSE, sizeof(BetUser));
-
     return new;
 }
 
@@ -86,12 +89,19 @@ user_new(void)
 void
 user_set_up_team_new_game(User *user)
 {
+#ifdef DEBUG
+    printf("user_set_up_team_new_game\n");
+#endif
+
     gchar buf[SMALL];
     gint rndom;
 
+    /* If the user chose to start in a different league than
+       his team is originally in, the league is stored in the scout
+       variable. */
     if(user->scout == -1)
     {
-	user_set_up_team(user);
+	user_set_up_team(user, TRUE);
 	user_history_add(user, USER_HISTORY_START_GAME, 
 			 user->tm->name, 
 			 league_cup_get_name_string(user->tm->clid), NULL, NULL);
@@ -114,25 +124,32 @@ user_set_up_team_new_game(User *user)
 			 user->tm->name, 
 			 league_cup_get_name_string(user->tm->clid), NULL, NULL);
 
-	user_set_up_team(user);
+	user_set_up_team(user, TRUE);
     }
 }
 
 /** Set up finances, remove some players etc. for a new user team.
     @par am user The user whose team we set up. */
 void
-user_set_up_team(User *user)
+user_set_up_team(User *user, gboolean remove_players)
 {
+#ifdef DEBUG
+    printf("user_set_up_team\n");
+#endif
+
     gint i, j;
 
-    for(i=PLAYER_POS_DEFENDER; i<=PLAYER_POS_FORWARD; i++)
-	for(j=user->tm->players->len - 1; j > 10; j--)
-	    if(g_array_index(user->tm->players, Player, j).pos == i &&
-	       g_array_index(user->tm->players, Player, j).recovery != 1)
-	    {
-		player_remove_from_team(user->tm, j);
-		break;
-	    }
+    if(remove_players)
+    {
+	for(i=PLAYER_POS_DEFENDER; i<=PLAYER_POS_FORWARD; i++)
+	    for(j=user->tm->players->len - 1; j > 10; j--)
+		if(g_array_index(user->tm->players, Player, j).pos == i &&
+		   g_array_index(user->tm->players, Player, j).recovery != 1)
+		{
+		    player_remove_from_team(user->tm, j);
+		    break;
+		}
+    }
 
     for(i=0;i<user->tm->players->len;i++)
 	g_array_index(user->tm->players, Player, i).recovery = 0;
@@ -157,11 +174,14 @@ user_set_up_team(User *user)
 		   &user->options, -1);
 }
 
-
 /** Set the counters of the user to their initial values. */
 void
 user_set_up_counters(User *user)
 {
+#ifdef DEBUG
+    printf("user_set_up_counters\n");
+#endif
+
     gint i;
 
     for(i=0;i<COUNT_USER_END;i++)
@@ -169,12 +189,19 @@ user_set_up_counters(User *user)
 
     user->counters[COUNT_USER_LOAN] =
 	user->counters[COUNT_USER_POSITIVE] = -1;
+    user->counters[COUNT_USER_TRAININGS_LEFT_SEASON] = 
+	const_int("int_training_camps_per_season");
 }
+
 /** Set up the user's finances when he's got a new team.
     @param user The user we set up the finances for. */
 void
 user_set_up_finances(User *user)
 {
+#ifdef DEBUG
+    printf("user_set_up_finances\n");
+#endif
+
     gint i;
 
     for(i=0; i<MON_OUT_END;i++)
@@ -182,7 +209,9 @@ user_set_up_finances(User *user)
     for(i=0; i<MON_IN_END;i++)
 	user->money_in[0][i] = user->money_in[1][i] = 0;
     
-    user->debt = 0;
+    user->debt = 
+        user->alr_start_week =
+        user->alr_weekly_installment = 0;
     user->money = 
 	math_round_integer(user->tm->stadium.capacity * 
 			   math_rndi(const_int("int_initial_money_lower"),
@@ -196,6 +225,10 @@ user_set_up_finances(User *user)
 void
 user_remove(gint idx, gboolean regenerate_team)
 {
+#ifdef DEBUG
+    printf("user_remove\n");
+#endif
+
     gint i;
 
     if(regenerate_team)
@@ -206,6 +239,8 @@ user_remove(gint idx, gboolean regenerate_team)
 	g_array_free(usr(idx).tm->players, TRUE);
 	usr(idx).tm->players = g_array_new(FALSE, FALSE, sizeof(Player));
 
+	usr(idx).tm->luck = 1;
+
 	team_generate_players_stadium(usr(idx).tm, 0);
 	for(i=0;i<usr(idx).tm->players->len;i++)
 	    g_array_index(usr(idx).tm->players, Player, i).team = usr(idx).tm;
@@ -223,6 +258,10 @@ user_remove(gint idx, gboolean regenerate_team)
 void
 user_set_player_list_attributes(const User *user, PlayerListAttribute *attribute, gint list_number)
 {
+#ifdef DEBUG
+    printf("user_set_player_list_attributes\n");
+#endif
+
     gint i, cnt = 0;
     gchar prefix[SMALL];
 
@@ -236,10 +275,31 @@ user_set_player_list_attributes(const User *user, PlayerListAttribute *attribute
 	}
 }
 
+/** Find out whether there are user events. */
+gboolean
+query_user_events()
+{
+#ifdef DEBUG
+    printf("query_user_events\n");
+#endif
+
+    gint i;
+
+    for(i=0;i<users->len;i++)
+	if(usr(i).events->len!=0)
+	    return TRUE;
+
+    return FALSE;
+}
+
 /** Find out whether there are user games at the specified date. */
 gboolean
 query_user_games_in_week_round(gint week_number, gint week_round_number)
 {
+#ifdef DEBUG
+    printf("query_user_games_in_week_round\n");
+#endif
+
     gint i;
 
     for(i=0;i<users->len;i++)
@@ -253,6 +313,10 @@ query_user_games_in_week_round(gint week_number, gint week_round_number)
 gboolean
 query_user_game_in_week_round(gint usr_idx, gint week_number, gint week_round_number)
 {
+#ifdef DEBUG
+    printf("query_user_game_in_week_round\n");
+#endif
+
     gint i, j;
 
     for(i=0;i<ligs->len;i++)
@@ -297,6 +361,10 @@ user_from_team(const Team *tm)
 void
 user_job_offer(User *user)
 {
+#ifdef DEBUG
+    printf("user_job_offer\n");
+#endif
+
     Team *new_team = NULL;
 
     if(math_rnd(0, 1) > const_float("float_user_success_counter_check") ||
@@ -335,6 +403,10 @@ user_job_offer(User *user)
 void
 user_weekly_update_counters(User *user)
 {
+#ifdef DEBUG
+    printf("user_weekly_update_counters\n");
+#endif
+
     gint rank = team_get_league_rank(user->tm);
     gint teamslen = ((GArray*)(league_cup_get_teams(user->tm->clid)))->len;
     gint rank_bounds[2] = 
@@ -346,6 +418,8 @@ user_weekly_update_counters(User *user)
     gint increase_capacity;
     gfloat increase_safety;
 
+    cnts[COUNT_USER_TRAININGS_WEEK] = 0;
+
     if(cnts[COUNT_USER_STADIUM_CAPACITY] > 0)
     {
 	increase_capacity = math_rndi(const_int("int_stadium_improvement_base_seats") - 
@@ -392,6 +466,10 @@ user_weekly_update_counters(User *user)
 Event
 user_event_new(void)
 {
+#ifdef DEBUG
+    printf("user_event_new\n");
+#endif
+
     Event new;
 
     new.user = NULL;
@@ -408,6 +486,10 @@ void
 user_event_add(User *user, gint type, gint value1, gint value2, 
 	       gpointer value_pointer, gchar *format, ...)
 {
+#ifdef DEBUG
+    printf("user_event_add\n");
+#endif
+
     Event new = user_event_new();
     gchar text[SMALL];
     va_list args;
@@ -437,6 +519,10 @@ user_event_add(User *user, gint type, gint value1, gint value2,
 void
 user_event_remove(User *user, gint idx)
 {
+#ifdef DEBUG
+    printf("user_event_remove\n");
+#endif
+
     free_event(&g_array_index(user->events, Event, idx));
     g_array_remove_index(user->events, idx);
 }
@@ -444,7 +530,12 @@ user_event_remove(User *user, gint idx)
 /** Show the next event for the current user. */
 void
 user_event_show_next(void)
-{    
+{
+#ifdef DEBUG
+    printf("user_event_show_next\n");
+#endif
+
+     
     Event *event = NULL;
     gchar buf[SMALL],
 	buf2[SMALL], buf3[SMALL];
@@ -517,6 +608,12 @@ user_event_show_next(void)
 		    event->value_string,
 		    ((Team*)event->value_pointer)->name, buf2, buf3);
 	    break;
+	case EVENT_TYPE_TRANSFER_OFFER_REJECTED_STARS:
+	    /* A player from a team has rejected a transfer offer. */
+	    game_gui_show_warning(_("%s of %s has rejected your offer because your team has too many star players already. 'A player of my caliber doesn't play second fiddle,' he was quoted."),
+				  event->value_string,
+				  ((Team*)event->value_pointer)->name);
+	    break;
 	case EVENT_TYPE_TRANSFER_OFFER_MONEY:
 	    /* Buy a player from a team. */
 	    game_gui_show_warning(_("You didn't have enough money to buy %s from %s."),
@@ -551,13 +648,20 @@ user_event_show_next(void)
 void
 user_change_team(User *user, Team *tm)
 {
+#ifdef DEBUG
+    printf("user_change_team\n");
+#endif
+
     gint i;
     gint success = user->counters[COUNT_USER_SUCCESS];
 
+    /* Reset the ticketprice of the old team to the default value */
+    user->tm->stadium.ticket_price = const_int("int_team_stadium_ticket_price");
+
     user->tm = tm;
     user->team_id = tm->id;
 
-    user_set_up_team(user);
+    user_set_up_team(user, FALSE);
 
     user->counters[COUNT_USER_NEW_SPONSOR] = 0;
     user->counters[COUNT_USER_SUCCESS] = (success < 0) ?
@@ -567,7 +671,7 @@ user_change_team(User *user, Team *tm)
     user->sponsor = user_get_sponsor(&current_user);    
 
     for(i=user->events->len - 1; i >= 0; i--)
-	user_event_remove(user, i);    
+	user_event_remove(user, i);
 }
 
 /** Check whether one of the user teams has an unfit player
@@ -575,6 +679,10 @@ user_change_team(User *user, Team *tm)
 gboolean
 query_user_teams_have_unfit(void)
 {
+#ifdef DEBUG
+    printf("query_user_teams_have_unfit\n");
+#endif
+
     gint i, j;
 
     for(i=0;i<users->len;i++)
@@ -595,6 +703,10 @@ query_user_teams_have_unfit(void)
 gint
 user_history_compare(gconstpointer a, gconstpointer b)
 {
+#ifdef DEBUG
+    printf("user_history_compare\n");
+#endif
+
     gint return_value = 0;
     const UserHistory *his1 = (const UserHistory*)a,
 	*his2 = (const UserHistory*)b;
@@ -617,6 +729,10 @@ user_history_add(User *user, gint type, const gchar *team_name,
 		 const gchar* string0, const gchar *string1,
 		 const gchar *string2)
 {
+#ifdef DEBUG
+    printf("user_history_add\n");
+#endif
+
     gint i;
     UserHistory new_history;
     UserHistory *his = &new_history;
@@ -696,6 +812,10 @@ user_history_add(User *user, gint type, const gchar *team_name,
 void
 user_history_to_string(const UserHistory *history, gchar *buf)
 {
+#ifdef DEBUG
+    printf("user_history_to_string\n");
+#endif
+
     switch(history->type)
     {
 	default:
@@ -776,21 +896,30 @@ user_history_to_string(const UserHistory *history, gchar *buf)
 void
 user_add_cup_success(User *user, const Cup *cup, gint round, gint type)
 {
+#ifdef DEBUG
+    printf("user_add_cup_success\n");
+#endif
+
+    gboolean international, national;
+
+    international = query_league_cup_has_property(cup->id, "international");
+    national = query_league_cup_has_property(cup->id, "national");
+
     if(type == USER_HISTORY_WIN_FINAL)
     {
-	if(query_cup_is_international(cup->id))
+	if(international)
 	    user->counters[COUNT_USER_SUCCESS] +=
 		const_int("int_user_success_international_winner");
-	else if(query_cup_is_national(cup->id))
+	else if(national)
 	    user->counters[COUNT_USER_SUCCESS] +=
 		const_int("int_user_success_national_winner");
     }
     else if(type == USER_HISTORY_LOSE_FINAL)
     {
-	if(query_cup_is_international(cup->id))
+	if(international)
 	    user->counters[COUNT_USER_SUCCESS] +=
 		const_int("int_user_success_international_final");
-	else if(query_cup_is_national(cup->id))
+	else if(international)
 	    user->counters[COUNT_USER_SUCCESS] +=
 		const_int("int_user_success_national_winner");
 		const_int("int_user_success_national_final");
@@ -799,19 +928,19 @@ user_add_cup_success(User *user, const Cup *cup, gint round, gint type)
     {
 	if(round == cup_from_clid(cup->id)->rounds->len - 2)
 	{
-	    if(query_cup_is_international(cup->id))
+	    if(international)
 		user->counters[COUNT_USER_SUCCESS] +=
 		    const_int("int_user_success_international_semis");
-	    else if(query_cup_is_national(cup->id))
+	    else if(national)
 		user->counters[COUNT_USER_SUCCESS] +=
 		    const_int("int_user_success_national_semis");
 	}
 	else if(round == cup_from_clid(cup->id)->rounds->len - 3)
 	{
-	    if(query_cup_is_international(cup->id))
+	    if(international)
 		user->counters[COUNT_USER_SUCCESS] +=
 		    const_int("int_user_success_international_quarter");
-	    else if(query_cup_is_national(cup->id))
+	    else if(national)
 		user->counters[COUNT_USER_SUCCESS] +=
 		    const_int("int_user_success_national_quarter");
 	}
@@ -823,6 +952,10 @@ user_add_cup_success(User *user, const Cup *cup, gint round, gint type)
 gboolean
 query_user_no_turn(void)
 {
+#ifdef DEBUG
+    printf("query_user_no_turn\n");
+#endif
+
     gint i;
 
     for(i=0;i<users->len;i++)
@@ -836,6 +969,10 @@ query_user_no_turn(void)
 UserSponsor
 user_get_sponsor(const User *user)
 {
+#ifdef DEBUG
+    printf("user_get_sponsor\n");
+#endif
+
     UserSponsor new;
     gint suc_factor = (current_user.counters[COUNT_USER_SUCCESS] < 0) ? -1 : 1;
     gchar *names[18] =
@@ -924,6 +1061,10 @@ user_get_sponsor(const User *user)
 void
 user_show_sponsors(void)
 {
+#ifdef DEBUG
+    printf("user_show_sponsors\n");
+#endif
+
     gint i, num_offers;
     GArray *sponsors = g_array_new(FALSE, FALSE, sizeof(UserSponsor));
     UserSponsor sponsor;
@@ -964,6 +1105,10 @@ user_show_sponsors(void)
 void
 user_show_sponsor_continue(void)
 {
+#ifdef DEBUG
+    printf("user_show_sponsor_continue\n");
+#endif
+
     GArray *sponsors = g_array_new(FALSE, FALSE, sizeof(UserSponsor));
     UserSponsor sponsor;
     gchar buf[SMALL];
@@ -991,16 +1136,21 @@ user_show_sponsor_continue(void)
 void
 user_mm_load_file(const gchar *filename, GArray *mmatches)
 {
-    gchar prefix[SMALL], filename_local[SMALL],
+#ifdef DEBUG
+    printf("user_mm_load_file\n");
+#endif
+
+    GString *prefix = g_string_new(""); 
+    gchar filename_local[SMALL],
 	matches_file[SMALL];
     GArray *mm_array = (mmatches == NULL) ?
 	current_user.mmatches : mmatches;
     
     strcpy(filename_local, filename);
-    strncpy(prefix, filename_local, strlen(filename_local) - 8);
-    prefix[strlen(filename_local) - 8] = '\0';
+    g_string_append_len(prefix, filename_local, strlen(filename_local) - 8);
+    //prefix[strlen(filename_local) - 8] = '\0';
 
-    sprintf(matches_file, "%s___mmatches", prefix);
+    sprintf(matches_file, "%s___mmatches", prefix->str);
 
     file_decompress(filename_local);
     
@@ -1009,11 +1159,13 @@ user_mm_load_file(const gchar *filename, GArray *mmatches)
 
     xml_mmatches_read(matches_file, mm_array);
 
-    strcat(prefix, "___*");
+    g_string_append(prefix, "___*");
     file_remove_files(prefix);
 
     if(mmatches == NULL)
 	misc_string_assign(&current_user.mmatches_file, filename_local);
+	
+	g_string_free(prefix, TRUE);
 }
 
 /** Add the last match to the MM file.
@@ -1023,6 +1175,10 @@ user_mm_load_file(const gchar *filename, GArray *mmatches)
 void
 user_mm_add_last_match(gboolean load_file, gboolean save_file)
 {
+#ifdef DEBUG
+    printf("user_mm_add_last_match\n");
+#endif
+
     MemMatch new;
     const Fixture *fix = current_user.live_game.fix;
     gchar buf[SMALL];
@@ -1031,7 +1187,7 @@ user_mm_add_last_match(gboolean load_file, gboolean save_file)
 	new.competition_name = g_string_new(league_cup_get_name_string(fix->clid));
     else
     {
-	cup_round_name(fix, buf);
+	fixture_get_cup_round_name(fix, buf);
 	new.competition_name = g_string_new("");
 	g_string_printf(new.competition_name, "%s %s", 
 			league_cup_get_name_string(fix->clid), buf);
@@ -1064,6 +1220,10 @@ user_mm_add_last_match(gboolean load_file, gboolean save_file)
 void
 user_mm_save_file(const gchar *filename, const GArray *mmatches)
 {
+#ifdef DEBUG
+    printf("user_mm_save_file\n");
+#endif
+
     gchar prefix[SMALL];
 
     strncpy(prefix, filename, strlen(filename) - 8);
@@ -1081,6 +1241,10 @@ user_mm_save_file(const gchar *filename, const GArray *mmatches)
 void
 user_mm_set_filename(const gchar *filename, gchar *dest)
 {
+#ifdef DEBUG
+    printf("user_mm_set_filename\n");
+#endif
+
     gchar buf[SMALL];
 
     if(g_str_has_suffix(filename, ".bmm.zip"))
@@ -1111,6 +1275,10 @@ user_mm_set_filename(const gchar *filename, gchar *dest)
 void
 user_mm_import_file(const gchar *filename)
 {
+#ifdef DEBUG
+    printf("user_mm_import_file\n");
+#endif
+
     GArray *mm_array = g_array_new(FALSE, FALSE, sizeof(MemMatch));
     gint i;
 
@@ -1126,6 +1294,10 @@ user_mm_import_file(const gchar *filename)
 void
 user_mm_export_file(const gchar *filename)
 {
+#ifdef DEBUG
+    printf("user_mm_export_file\n");
+#endif
+
     gchar buf[SMALL];
     GArray *mmatches = g_array_new(FALSE, FALSE, sizeof(MemMatch));
 
