@@ -27,6 +27,7 @@
 #include "debug.h"
 #include "file.h"
 #include "finance.h"
+#include "fixture.h"
 #include "free.h"
 #include "game_gui.h"
 #include "gui.h"
@@ -37,6 +38,7 @@
 #include "load_save.h"
 #include "main.h"
 #include "maths.h"
+#include "misc.h"
 #include "misc_callback_func.h"
 #include "misc_interface.h"
 #include "misc2_interface.h"
@@ -45,6 +47,8 @@
 #include "option_gui.h"
 #include "options_interface.h"
 #include "support.h"
+#include "training.h"
+#include "training_interface.h"
 #include "transfer.h"
 #include "treeview.h"
 #include "treeview2.h"
@@ -56,6 +60,10 @@
 void
 window_show_splash(void)
 {
+#ifdef DEBUG
+    printf("window_show_splash\n");
+#endif
+
     window_create(WINDOW_SPLASH);
 
     treeview_show_contributors(
@@ -69,6 +77,10 @@ window_show_splash(void)
 void
 window_splash_show_hint(void)
 {
+#ifdef DEBUG
+    printf("window_splash_show_hint\n");
+#endif
+
     gchar buf[SMALL];
 
     gtk_label_set_text(
@@ -87,6 +99,10 @@ window_splash_show_hint(void)
 void
 window_load_hint_number(void)
 {
+#ifdef DEBUG
+    printf("window_load_hint_number\n");
+#endif
+
     gchar filename[SMALL];
     gchar dir[SMALL];
     FILE *fil;
@@ -121,6 +137,10 @@ window_load_hint_number(void)
 void
 window_save_hint_number(void)
 {
+#ifdef DEBUG
+    printf("window_save_hint_number\n");
+#endif
+
     gchar filename[SMALL];
     gchar dir[SMALL];
     FILE *fil;
@@ -145,12 +165,19 @@ window_save_hint_number(void)
 void
 window_show_progress(gint pictype)
 {
+#ifdef DEBUG
+    printf("window_show_progress\n");
+#endif
+
     GPtrArray *pics = NULL;
     const gchar *picdir = NULL;
     gchar buf[SMALL];
     gchar *buf2 = NULL;
     GtkImage *image = NULL;
 
+    if(sett_int("int_opt_goto_mode"))
+        return;
+
     window_create(WINDOW_PROGRESS);
 
     if(pictype == PIC_TYPE_NONE ||
@@ -210,6 +237,10 @@ window_show_progress(gint pictype)
 void
 window_show_bets(void)
 {
+#ifdef DEBUG
+    printf("window_show_bets\n");
+#endif
+
     window_create(WINDOW_BETS);
 
     gtk_toggle_button_set_active(
@@ -230,11 +261,15 @@ window_show_bets(void)
 void
 window_show_help(gint page)
 {
+#ifdef DEBUG
+    printf("window_show_help\n");
+#endif
+
     gchar buf[SMALL];
 
     window_create(WINDOW_HELP);
 
-    sprintf(buf, "<span %s>Bygfoot Football Manager %s</span>\n(c) 2005 Győző Both (gyboth@bygfoot.com)\nhttp://bygfoot.sourceforge.net", const_app("string_help_window_program_name_attribute"), VERS);
+    sprintf(buf, "<span %s>Bygfoot Football Manager %s</span>\n(c) %s Győző Both (gyboth@bygfoot.com)\nhttp://bygfoot.sourceforge.net", const_app("string_help_window_program_name_attribute"), VERS, YEAR);
     gtk_label_set_markup(GTK_LABEL(lookup_widget(window.help, "label_about")), buf);
 
     treeview_show_contributors(
@@ -245,6 +280,20 @@ window_show_help(gint page)
     gtk_notebook_set_current_page(GTK_NOTEBOOK(lookup_widget(window.help, "notebook1")), page);
 }
 
+static void
+is_capital_sensitive (GtkCellLayout   *cell_layout,
+		      GtkCellRenderer *cell,
+		      GtkTreeModel    *tree_model,
+		      GtkTreeIter     *iter,
+		      gpointer         data)
+{
+  gboolean sensitive;
+
+  sensitive = !gtk_tree_model_iter_has_child (tree_model, iter);
+
+  g_object_set (cell, "sensitive", sensitive, NULL);
+}
+
 /**
    Show the country selection window. All files with prefix
    'country_' from $HOME/.bygfoot/definitions are appended to a combo box.
@@ -252,6 +301,10 @@ window_show_help(gint page)
 void
 window_show_startup(void)
 {
+#ifdef DEBUG
+    printf("window_show_startup\n");
+#endif
+
     GtkWidget *window_startup =
 	window_create(WINDOW_STARTUP);
     GtkWidget *combo_country =
@@ -259,6 +312,7 @@ window_show_startup(void)
     GPtrArray *country_files = NULL;
     GtkTreeModel *model = NULL;
     GtkCellRenderer *renderer = NULL;
+    gchar *last_country = file_load_text_from_saves("last_country");
     
     country_files = file_get_country_files();
 
@@ -279,9 +333,24 @@ window_show_startup(void)
     language_pick_country(country_files);
     model = treeview_create_country_list(country_files);
     gtk_combo_box_set_model(GTK_COMBO_BOX(combo_country), model);
+    gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo_country),
+					renderer,
+					is_capital_sensitive,
+					NULL, NULL);
+
     g_object_unref(model);
 
-    gtk_combo_box_set_active(GTK_COMBO_BOX(combo_country), 0);
+    if(country.sid != NULL)
+        misc_callback_show_team_list(combo_country, country.sid);        
+    else if(last_country != NULL)
+        misc_callback_show_team_list(combo_country, last_country);        
+    else
+        misc_callback_show_team_list(combo_country, (const gchar*)g_ptr_array_index(country_files, country_files->len - 1));
+
+    if(last_country != NULL)
+        g_free(last_country);
+
+    //gtk_combo_box_set_active(GTK_COMBO_BOX(combo_country), country_index);
 
     free_gchar_array(&country_files);
 }
@@ -290,6 +359,10 @@ window_show_startup(void)
 void
 window_show_file_sel(void)
 {
+#ifdef DEBUG
+    printf("window_show_file_sel\n");
+#endif
+
     gchar buf[SMALL];
     const gchar *home = g_get_home_dir();
     gchar *filename = NULL;
@@ -410,6 +483,10 @@ window_show_file_sel(void)
 void
 window_show_mmatches(void)
 {
+#ifdef DEBUG
+    printf("window_show_mmatches\n");
+#endif
+
     if(window.mmatches == NULL)
 	window_create(WINDOW_MMATCHES);
     treeview2_show_mmatches();
@@ -422,6 +499,10 @@ window_show_mmatches(void)
 void
 window_show_options(void)
 {
+#ifdef DEBUG
+    printf("window_show_options\n");
+#endif
+
     window_create(WINDOW_OPTIONS);
 
     option_gui_set_up_window();
@@ -431,6 +512,10 @@ window_show_options(void)
 void
 window_show_menu_player(GdkEvent *event)
 {
+#ifdef DEBUG
+    printf("window_show_menu_player\n");
+#endif
+
     if(window.menu_player != NULL)
 	window_destroy(&window.menu_player);
 
@@ -444,6 +529,10 @@ window_show_menu_player(GdkEvent *event)
 void
 window_show_menu_youth(GdkEvent *event)
 {
+#ifdef DEBUG
+    printf("window_show_menu_youth\n");
+#endif
+
     if(window.menu_youth != NULL)
 	window_destroy(&window.menu_youth);
 
@@ -457,8 +546,12 @@ window_show_menu_youth(GdkEvent *event)
     according to the arguments. */
 void
 window_show_digits(const gchar *text_main, const gchar* text1, gint value1, 
-		   const gchar* text2, gint value2)
+		   const gchar* text2, gint value2, gboolean show_alr)
 {
+#ifdef DEBUG
+    printf("window_show_digits\n");
+#endif
+
     GtkLabel *label_main, *label_1, *label_2;
     GtkSpinButton *spinbutton1, *spinbutton2;
 
@@ -492,12 +585,19 @@ window_show_digits(const gchar *text_main, const gchar* text1, gint value1,
 	gtk_label_set_text(label_2, text2);
     else
 	gtk_widget_hide(GTK_WIDGET(label_2)->parent);
+
+    if(show_alr)
+        gtk_widget_show(lookup_widget(window.digits, "button_digits_alr"));
 }
 
 /** Show the stadium window for the current user. */
 void
 window_show_stadium(void)
 {
+#ifdef DEBUG
+    printf("window_show_stadium\n");
+#endif
+
     gchar buf[SMALL];
     const Team *tm = current_user.tm;
     GtkLabel *label_capacity,
@@ -506,6 +606,7 @@ window_show_stadium(void)
     GtkProgressBar *progressbar_safety,
 	*progressbar_average_attendance;
     gfloat average_attendance_perc = 0;
+    GtkSpinButton *spin_ticket_price;
 
     window_create(WINDOW_STADIUM);
 
@@ -514,6 +615,14 @@ window_show_stadium(void)
     label_average_attendance = GTK_LABEL(lookup_widget(window.stadium, "label_average_attendance"));
     label_name = GTK_LABEL(lookup_widget(window.stadium, "label_stadium_name"));
     
+    spin_ticket_price = GTK_SPIN_BUTTON(lookup_widget(window.stadium, "spin_ticket_price"));
+    gtk_spin_button_set_value(spin_ticket_price, tm->stadium.ticket_price);
+    /* Set the lower bound to constant_ticket_price-(1/constant_ticket_attendance)
+       +1 So that we can't divide by 0 or negative numbers*/
+    gfloat lower_bound = const_int("int_team_stadium_ticket_price")-(1/const_float("float_team_stadium_price_attendance_factor"))+1;
+
+    gtk_spin_button_set_range(spin_ticket_price, lower_bound, 100);
+
     progressbar_safety = GTK_PROGRESS_BAR(lookup_widget(window.stadium, "progressbar_safety"));
     progressbar_average_attendance = GTK_PROGRESS_BAR(lookup_widget(window.stadium, "progressbar_average_attendance"));
 
@@ -558,6 +667,10 @@ window_show_stadium(void)
 gboolean
 window_show(gpointer window)
 {
+#ifdef DEBUG
+    printf("window_show\n");
+#endif
+
     gtk_widget_show((GtkWidget*)window);
 
     return FALSE;
@@ -568,6 +681,10 @@ window_show(gpointer window)
 void
 window_show_yesno(const gchar *text)
 {
+#ifdef DEBUG
+    printf("window_show_yesno\n");
+#endif
+
     window_create(WINDOW_YESNO);
     gtk_label_set_text(GTK_LABEL(lookup_widget(window.yesno, "label_yesno")), text);
 }
@@ -577,6 +694,10 @@ window_show_yesno(const gchar *text)
 void
 window_show_transfer_dialog(const gchar *text)
 {
+#ifdef DEBUG
+    printf("window_show_transfer_dialog\n");
+#endif
+
     window_create(WINDOW_TRANSFER_DIALOG);
     gtk_label_set_text(GTK_LABEL(lookup_widget(window.transfer_dialog, "label_transfer_dialog")), text);
 }
@@ -586,6 +707,10 @@ window_show_transfer_dialog(const gchar *text)
 void
 window_live_set_up(void)
 {
+#ifdef DEBUG
+    printf("window_live_set_up\n");
+#endif
+
     GtkSpinButton *sb_speed = 
 	GTK_SPIN_BUTTON(lookup_widget(window.live, "spinbutton_speed"));
     gfloat user_option = (gfloat)option_int("int_opt_user_live_game_speed", 
@@ -608,6 +733,10 @@ window_live_set_up(void)
 void
 window_main_save_geometry(void)
 {
+#ifdef DEBUG
+    printf("window_main_save_geometry\n");
+#endif
+
     gchar filename[SMALL];
     gchar dir[SMALL];
     FILE *fil = NULL;
@@ -640,6 +769,10 @@ window_main_save_geometry(void)
 void
 window_main_load_geometry(void)
 {
+#ifdef DEBUG
+    printf("window_main_load_geometry\n");
+#endif
+
     gchar filename[SMALL];
     gchar dir[SMALL];
     OptionList optionlist;
@@ -865,6 +998,30 @@ window_create(gint window_type)
 		window.splash = create_window_splash();
 	    wind = window.splash;
 	    break;
+    case WINDOW_TRAINING_CAMP:
+        if(window.training_camp != NULL)
+            g_warning("window_create: called on already existing window\n");
+        else
+            window.training_camp = create_window_training_camp();
+        wind = window.training_camp;
+        strcpy(buf, _("Training camp"));
+        break;
+    case WINDOW_ALR:
+        if(window.alr != NULL)
+            g_warning("window_create: called on already existing window\n");
+        else
+            window.alr = create_window_alr();
+        wind = window.alr;
+        strcpy(buf, _("Automatic loan repayment"));
+        break;
+    case WINDOW_NEWS:
+        if(window.news != NULL)
+            g_warning("window_create: called on already existing window\n");
+        else
+            window.news = create_window_news();
+        wind = window.news;
+        strcpy(buf, _("Bygfoot News"));
+        break;
     }
 
     if(window_type != WINDOW_FILE_CHOOSER)
@@ -886,6 +1043,10 @@ window_create(gint window_type)
 void
 window_destroy(GtkWidget **wind)
 {
+#ifdef DEBUG
+    printf("window_destroy\n");
+#endif
+
     if(*wind == NULL)
 	return;
 
@@ -901,3 +1062,115 @@ window_destroy(GtkWidget **wind)
 
     *wind = NULL;
 }
+
+/* Show the training camp window for the current user. */
+void
+window_show_training_camp(void)
+{
+#ifdef DEBUG
+    printf("window_show_training_camp\n");
+#endif
+
+	GtkEntry *tfCosts;
+	GtkWidget *rb_camp1;
+    GtkWidget *rb_camp2;
+    GtkWidget *rb_camp3;
+    GtkLabel *l_costs;
+    GtkLabel *l_recreation;
+    GtkLabel *l_training;
+    GtkLabel *l_camp_points;
+    GtkHScale *hs_recreation;
+    GtkHScale *hs_training;
+    GtkHScale *hs_camp_points;
+	gchar buf[SMALL];
+	
+    window_create(WINDOW_TRAINING_CAMP);
+        
+    // Initialize entry costs
+    misc_print_grouped_int(
+	math_round_integer(finance_wage_unit(current_user.tm) * const_float("float_training_camp_factor1"), -2),
+	buf);
+    tfCosts = GTK_ENTRY(lookup_widget(window.training_camp, "tf_costs"));
+    gtk_entry_set_text (tfCosts, buf);
+    
+    // Initialize radio group camp
+    rb_camp1 = GTK_WIDGET(lookup_widget(window.training_camp, "rb_camp1"));
+    rb_camp2 = GTK_WIDGET(lookup_widget(window.training_camp, "rb_camp2"));
+    rb_camp3 = GTK_WIDGET(lookup_widget(window.training_camp, "rb_camp3"));
+
+    if(opt_user_int("int_opt_user_training_camp_hotel") == TRAINING_CAMP_HOTEL_GOOD)
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(rb_camp1), TRUE);
+    else if(opt_user_int("int_opt_user_training_camp_hotel") == TRAINING_CAMP_HOTEL_FIRST)
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(rb_camp2), TRUE);
+    else
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(rb_camp3), TRUE);
+    
+    //Initialize labels
+    l_costs = GTK_LABEL(lookup_widget(window.training_camp, "l_costs"));
+    l_recreation = GTK_LABEL(lookup_widget(window.training_camp, "l_recreation"));
+    l_training = GTK_LABEL(lookup_widget(window.training_camp, "l_training"));
+    l_camp_points = GTK_LABEL(lookup_widget(window.training_camp, "l_camp_points"));
+    gtk_misc_set_alignment (GTK_MISC(l_costs), 0.0, 0.5);
+    gtk_misc_set_alignment (GTK_MISC(l_recreation), 0.0, 0.5);
+    gtk_misc_set_alignment (GTK_MISC(l_training), 0.0, 0.5);
+    gtk_misc_set_alignment (GTK_MISC(l_camp_points), 0.0, 0.5);
+    
+    //Initialize hScales
+    hs_recreation = GTK_HSCALE(lookup_widget(window.training_camp, "hs_recreation"));
+    hs_training = GTK_HSCALE(lookup_widget(window.training_camp, "hs_training"));
+    hs_camp_points = GTK_HSCALE(lookup_widget(window.training_camp, "hs_camp_points"));
+    gtk_range_set_range (GTK_RANGE(hs_recreation), CAMP_SCALE_MIN, CAMP_SCALE_MAX);
+    gtk_range_set_range (GTK_RANGE(hs_training), CAMP_SCALE_MIN, CAMP_SCALE_MAX);
+    gtk_range_set_range (GTK_RANGE(hs_camp_points), CAMP_SCALE_MIN, CAMP_SCALE_MAX);
+    gtk_range_set_value (GTK_RANGE(hs_recreation), opt_user_int("int_opt_user_training_camp_recreation"));
+    gtk_range_set_value (GTK_RANGE(hs_training), 
+			 CAMP_SCALE_MAX - opt_user_int("int_opt_user_training_camp_recreation"));
+    gtk_range_set_value (GTK_RANGE(hs_camp_points), CAMP_SCALE_MIN);
+    gtk_scale_set_digits (GTK_SCALE(hs_recreation), 0);
+    gtk_scale_set_digits (GTK_SCALE(hs_training), 0);
+    gtk_scale_set_digits (GTK_SCALE(hs_camp_points), 0);
+    gtk_widget_set_sensitive (GTK_WIDGET(hs_recreation), FALSE);
+    gtk_widget_set_sensitive (GTK_WIDGET(hs_training), FALSE);
+    gtk_widget_set_sensitive (GTK_WIDGET(hs_camp_points), FALSE);
+    
+	GdkColor color;
+    //gtk_widget_modify_fg(GTK_WIDGET(hs_recreation), GTK_STATE_INSENSITIVE , NULL);
+    //gtk_widget_modify_fg(GTK_WIDGET(hs_training), GTK_STATE_INSENSITIVE , NULL);
+    //gtk_widget_modify_fg(GTK_WIDGET(hs_camp_points), GTK_STATE_INSENSITIVE , NULL);
+    //gtk_widget_modify_bg(GTK_WIDGET(hs_recreation), GTK_STATE_NORMAL, NULL);
+    gdk_color_parse("black", &color);
+    gtk_widget_modify_fg(GTK_WIDGET(hs_recreation), GTK_STATE_INSENSITIVE , &color);
+    gtk_widget_modify_fg(GTK_WIDGET(hs_training), GTK_STATE_INSENSITIVE , &color);
+    gtk_widget_modify_fg(GTK_WIDGET(hs_camp_points), GTK_STATE_INSENSITIVE , &color);
+    gtk_widget_modify_bg(GTK_WIDGET(hs_recreation), GTK_STATE_NORMAL, &color);
+    gtk_widget_modify_bg(GTK_WIDGET(hs_training), GTK_STATE_NORMAL, &color);
+    gtk_widget_modify_bg(GTK_WIDGET(hs_camp_points), GTK_STATE_NORMAL, &color);
+}
+
+/** Create and set up the debt repayment window. */
+void
+window_show_alr(void)
+{
+#ifdef DEBUG
+    printf("window_show_alr\n");
+#endif
+
+    gchar weekly_installment[SMALL],
+        debt[SMALL];
+
+    window_create(WINDOW_ALR);
+
+    misc_print_grouped_int(current_user.alr_weekly_installment, weekly_installment);
+    misc_print_grouped_int(-current_user.debt, debt);
+
+    gui_label_set_text_from_int(GTK_LABEL(lookup_widget(window.alr, "label_current_start_week")),
+                                current_user.alr_start_week, FALSE);
+    gtk_label_set_text(GTK_LABEL(lookup_widget(window.alr, "label_current_weekly_installment")), weekly_installment);
+    gtk_label_set_text(GTK_LABEL(lookup_widget(window.alr, "label_alr_debt")), debt);
+
+    gtk_spin_button_set_range(GTK_SPIN_BUTTON(lookup_widget(window.alr, "spinbutton_start_week")),
+                              week + 1, MIN(week + current_user.counters[COUNT_USER_LOAN], fixture_get_last_scheduled_week()));
+    gtk_spin_button_set_range(GTK_SPIN_BUTTON(lookup_widget(window.alr, "spinbutton_weekly_installment")),
+                              0, -current_user.debt * powf(1 + current_user.debt_interest, const_int("int_finance_payback_weeks")) + 1);
+}
+
