@@ -1,3 +1,28 @@
+/*
+   xml_name.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "file.h"
 #include "free.h"
 #include "misc.h"
@@ -31,6 +56,10 @@ xml_name_read_start_element (GMarkupParseContext *context,
 			     gpointer             user_data,
 			     GError             **error)
 {
+#ifdef DEBUG
+    printf("xml_name_read_start_element\n");
+#endif
+
     if(strcmp(element_name, TAG_NAMES) == 0)
 	state = STATE_NAMES;
     else if(strcmp(element_name, TAG_FIRST_NAME) == 0)
@@ -49,6 +78,10 @@ xml_name_read_end_element    (GMarkupParseContext *context,
 			      gpointer             user_data,
 			      GError             **error)
 {
+#ifdef DEBUG
+    printf("xml_name_read_end_element\n");
+#endif
+
     if(strcmp(element_name, TAG_FIRST_NAME) == 0 ||
        strcmp(element_name, TAG_LAST_NAME) == 0)
        state = STATE_NAMES;
@@ -65,6 +98,10 @@ xml_name_read_text         (GMarkupParseContext *context,
 			    gpointer             user_data,
 			    GError             **error)
 {
+#ifdef DEBUG
+    printf("xml_name_read_text\n");
+#endif
+
     gchar buf[text_len + 1];
 
     strncpy(buf, text, text_len);
@@ -83,13 +120,17 @@ xml_name_read_text         (GMarkupParseContext *context,
 void
 xml_name_read(const gchar *sid, NameList *namelist)
 {
+#ifdef DEBUG
+    printf("xml_name_read\n");
+#endif
+
     gchar *file_name = NULL;
     GMarkupParser parser = {xml_name_read_start_element,
 			    xml_name_read_end_element,
 			    xml_name_read_text, NULL, NULL};
     GMarkupParseContext *context;
     gchar *file_contents;
-    gint length;
+    gsize length;
     GError *error = NULL;
     gchar buf[SMALL];
 
