@@ -37,6 +37,10 @@
 void
 youth_academy_new(User *user)
 {
+#ifdef DEBUG
+    printf("youth_academy_new\n");
+#endif
+
     gint i;
     gint num_of_youths = math_rndi(const_int("int_youth_academy_youths_lower"),
 				   const_int("int_youth_academy_youths_upper"));
@@ -67,6 +71,10 @@ youth_academy_new(User *user)
 void
 youth_academy_add_new_player(YouthAcademy *youth_academy)
 {
+#ifdef DEBUG
+    printf("youth_academy_add_new_player\n");
+#endif
+
     gint i;
     gfloat pos_probs[4] =
 	{const_float("float_youth_academy_pos_goalie"),
@@ -171,6 +179,10 @@ youth_academy_add_new_player(YouthAcademy *youth_academy)
 void
 youth_academy_update_weekly(void)
 {
+#ifdef DEBUG
+    printf("youth_academy_update_weekly\n");
+#endif
+
     gint i, j;
     YouthAcademy *ya = NULL;
 
@@ -197,14 +209,16 @@ youth_academy_update_weekly(void)
 	    if(g_array_index(ya->players, Player, j).age + 0.1 >
 	       const_float("float_player_age_lower") &&
 	       g_array_index(ya->players, Player, j).age + 0.08 <=
-	       const_float("float_player_age_lower"))
+	       const_float("float_player_age_lower") &&
+               !sett_int("int_opt_goto_mode"))
 		user_event_add(&usr(i), EVENT_TYPE_WARNING, -1, -1, NULL,
 			       _("Youth %s will be too old for the youth academy soon. Move him to your team or kick him out of the academy. Otherwise he'll probably look for another team to play in."), g_array_index(ya->players, Player, j).name);
 	    else if(g_array_index(ya->players, Player, j).age > const_float("float_player_age_lower"))
 	    {
-		user_event_add(&usr(i), EVENT_TYPE_WARNING, -1, -1, NULL,
-			       _("Youth %s thought he's old enough for a real contract and left your youth academy."),
-			       g_array_index(ya->players, Player, j).name);
+                if(!sett_int("int_opt_goto_mode"))
+                    user_event_add(&usr(i), EVENT_TYPE_WARNING, -1, -1, NULL,
+                                   _("Youth %s thought he's old enough for a real contract and left your youth academy."),
+                                   g_array_index(ya->players, Player, j).name);
 		free_player(&g_array_index(ya->players, Player, j));
 		g_array_remove_index(ya->players, j);
 	    }
@@ -233,10 +247,12 @@ youth_academy_update_weekly(void)
 		if(ya->players->len < const_int("int_youth_academy_max_youths"))
 		{
 		    youth_academy_add_new_player(ya);
-		    user_event_add(&usr(i), EVENT_TYPE_WARNING, -1, -1, NULL,
-				   _("A new youth registered at your youth academy."));
+
+                    if(!sett_int("int_opt_goto_mode"))
+                        user_event_add(&usr(i), EVENT_TYPE_WARNING, -1, -1, NULL,
+                                       _("A new youth registered at your youth academy."));
 		}
-		else
+		else if(!sett_int("int_opt_goto_mode"))
 		    user_event_add(&usr(i), EVENT_TYPE_WARNING, -1, -1, NULL,
 				   _("A new youth wanted to registered at your youth academy but there was no room for him."));
 	    }
